@@ -1,29 +1,39 @@
-# default methods, glm (almost default)
+# Arguments passed to or from other methods. For instance, when default methods, glm (almost default)
 
 #################### .default ----------------------
 
 #' Model Parameters
 #'
-#' Compute and extract model parameters. See the documentation for your object's class:
-#' \itemize{
-#'  \item{[Correlations, t-tests, ...][model_parameters.htest] (`htest`, `pairwise.htest`)}
-#'  \item{[ANOVAs][model_parameters.aov] (`aov`, `anova`, **afex**, ...)}
-#'  \item{[Regression models][model_parameters.default] (`lm`, `glm`, **survey**, ...)}
-#'  \item{[Additive models][model_parameters.cgam] (`gam`, `gamm`, ...)}
-#'  \item{[Zero-inflated models][model_parameters.zcpglm] (`hurdle`, `zeroinfl`, `zerocount`)}
-#'  \item{[Multinomial, ordinal and cumulative link models][model_parameters.mlm] (`bracl`, `multinom`, `mlm`, ...)}
-#'  \item{[Other special models][model_parameters.averaging] (`model.avg`, `betareg`, `glmx`, ...)}
-#'  \item{[Mixed models][model_parameters.merMod] (\pkg{lme4}, \pkg{nlme}, \pkg{glmmTMB}, \pkg{afex}, ...)}
-#'  \item{[Bayesian tests][model_parameters.BFBayesFactor] (\pkg{BayesFactor})}
-#'  \item{[Bayesian models][model_parameters.stanreg] (\pkg{rstanarm}, \pkg{brms}, \pkg{MCMCglmm}, \pkg{blavaan}, ...)}
-#'  \item{[PCA and FA][model_parameters.principal] (\pkg{psych})}
-#'  \item{[CFA and SEM][model_parameters.lavaan] (\pkg{lavaan})}
-#'  \item{[Cluster models][model_parameters.kmeans] (k-means, ...)}
-#'  \item{[Meta-Analysis via linear (mixed) models][model_parameters.rma] (`rma`, `metaplus`, \pkg{metaBMA}, ...)}
-#'  \item{[Hypothesis testing][model_parameters.glht] (`glht`, \pkg{PMCMRplus})}
-#'  \item{[Robust statistical tests][model_parameters.t1way] (\pkg{WRS2})}
-#'  \item{[Multiply imputed repeated analyses][model_parameters.mira] (`mira`)}
-#'  }
+#' Compute and extract model parameters. The available options and arguments depend
+#' on the modeling **package** and model `class`. Follow one of these links to read
+#' the model-specific documentation:
+#' - [Default method][model_parameters.default()]: `lm`, `glm`, **stats**, **censReg**,
+#'   **MASS**, **survey**, ...
+#' - [Additive models][model_parameters.cgam()]: **bamlss**, **gamlss**, **mgcv**,
+#'   **scam**, **VGAM**, `Gam`, `gamm`, ...
+#' - [ANOVA][model_parameters.aov()]: **afex**, `aov`, `anova`, ...
+#' - [Bayesian][model_parameters.stanreg()]: **BayesFactor**, **blavaan**, **brms**,
+#'   **MCMCglmm**, **posterior**, **rstanarm**, `bayesQR`, `bcplm`, `BGGM`, `blmrm`,
+#'   `blrm`, `mcmc.list`, `MCMCglmm`, ...
+#' - [Clustering][model_parameters.kmeans()]: **hclust**, **kmeans**, **mclust**, **pam**, ...
+#' - [Correlations, t-tests, etc.][model_parameters.htest()]: **lmtest**, `htest`,
+#'   `pairwise.htest`, ...
+#' - [Meta-Analysis][model_parameters.rma()]: **metaBMA**, **metafor**, **metaplus**, ...
+#' - [Mixed models][model_parameters.merMod()]: **cplm**, **glmmTMB**, **lme4**,
+#'   **lmerTest**, **nlme**, **ordinal**, **robustlmm**, **spaMM**, `mixed`, `MixMod`, ...
+#' - [Multinomial, ordinal and cumulative link][model_parameters.mlm()]: **brglm2**,
+#'   **DirichletReg**, **nnet**, **ordinal**, `mlm`, ...
+#' - [Multiple imputation][model_parameters.mira()]: **mice**
+#' - [PCA, FA, CFA, SEM][model_parameters.principal()]: **FactoMineR**, **lavaan**,
+#'   **psych**, `sem`, ...
+#' - [Zero-inflated and hurdle][model_parameters.zcpglm()]: **cplm**, **mhurdle**,
+#'   **pscl**, ...
+#' - [Other models][model_parameters.averaging()]: **aod**, **bbmle**, **betareg**,
+#'   **emmeans**, **epiR**, **ggeffects**, **glmx**, **ivfixed**, **ivprobit**,
+#'   **JRM**, **lmodel2**, **logitsf**, **marginaleffects**, **margins**, **maxLik**,
+#'   **mediation**, **mfx**, **multcomp**, **mvord**, **plm**, **PMCMRplus**,
+#'   **quantreg**, **selection**, **systemfit**, **tidymodels**, **varEST**,
+#'   **WRS2**, `bfsl`, `deltaMethod`, `fitdistr`, `mjoint`, `mle`, `model.avg`, ...
 #'
 #' @param model Statistical Model.
 #' @param ... Arguments passed to or from other methods. Non-documented
@@ -42,17 +52,21 @@
 #'   implemented in the
 #'   [**see**-package](https://easystats.github.io/see/), and a dedicated
 #'   method for use inside rmarkdown files,
-#'   [`print_md()`][print_md.parameters_model].
+#'   [`print_md()`][print_md.parameters_model]. \cr \cr **For developers**, if
+#'   speed performance is an issue, you can use the (undocumented) `pretty_names`
+#'   argument, e.g. `model_parameters(..., pretty_names = FALSE)`. This will
+#'   skip the formatting of the coefficient names and make `model_parameters()`
+#'   faster.
 #'
 #' @section Standardization of model coefficients:
-#' Standardization is based on [effectsize::standardize_parameters()]. In case
+#' Standardization is based on [standardize_parameters()]. In case
 #' of `standardize = "refit"`, the data used to fit the model will be
 #' standardized and the model is completely refitted. In such cases, standard
 #' errors and confidence intervals refer to the standardized coefficient. The
 #' default, `standardize = "refit"`, never standardizes categorical predictors
 #' (i.e. factors), which may be a different behaviour compared to other R
 #' packages or other software packages (like SPSS). To mimic behaviour of SPSS
-#' or packages such as \pkg{lm.beta}, use `standardize = "basic"`.
+#' or packages such as **lm.beta**, use `standardize = "basic"`.
 #'
 #' @section
 #'
@@ -113,8 +127,10 @@
 #' level 1 predictors (Hoffman 2015, page 342). A warning is given when a
 #' within-group variable is found to have access between-group variance.
 #'
+#' See also [package vignette](https://easystats.github.io/parameters/articles/standardize_parameters_effsize.html).
+#'
 #' @section Labeling the Degrees of Freedom:
-#' Throughout the \pkg{parameters} package, we decided to label the residual
+#' Throughout the **parameters** package, we decided to label the residual
 #' degrees of freedom *df_error*. The reason for this is that these degrees
 #' of freedom not always refer to the residuals. For certain models, they refer
 #' to the estimate error - in a linear model these are the same, but in - for
@@ -197,7 +213,7 @@
 #' to a \eqn{\chi}-squared distribution to compute CIs and p-values.
 #'
 #' `"profile"`
-#' - Applies to *non-Bayesian models* of class `glm`, `polr` or `glmmTMB`.
+#' - Applies to *non-Bayesian models* of class `glm`, `polr`, `merMod` or `glmmTMB`.
 #'   CIs computed by *profiling the likelihood curve for a parameter*, using
 #'   linear interpolation to find where likelihood ratio equals a critical value;
 #'   p-values computed using the Wald method with a *normal-distribution* (note:
@@ -259,6 +275,7 @@
 #' which is converted into a p-value using [`bayestestR::pd_to_p()`].
 #'
 #' @inheritSection format_parameters Interpretation of Interaction Terms
+#' @inheritSection print.parameters_model Global Options to Customize Messages and Tables when Printing
 #'
 #' @references
 #'
@@ -286,6 +303,16 @@ model_parameters <- function(model, ...) {
 # https://github.com/easystats/parameters/issues/455
 
 
+# Options -------------------------------------
+
+# getOption("parameters_summary"): show model summary
+# getOption("parameters_mixed_summary"): show model summary for mixed models
+# getOption("parameters_cimethod"): show message about CI approximation
+# getOption("parameters_exponentiate"): show warning about exp for log/logit links
+# getOption("parameters_labels"): use value/variable labels instead pretty names
+# getOption("parameters_interaction"): separator char for interactions
+# getOption("parameters_select"): default for the `select` argument
+
 
 #' @rdname model_parameters
 #' @export
@@ -302,51 +329,40 @@ parameters <- model_parameters
 #' @param bootstrap Should estimates be based on bootstrapped model? If
 #'   `TRUE`, then arguments of [Bayesian
 #'   regressions][model_parameters.stanreg] apply (see also
-#'   [`bootstrap_parameters()`][bootstrap_parameters]).
+#'   [`bootstrap_parameters()`]).
 #' @param iterations The number of bootstrap replicates. This only apply in the
 #'   case of bootstrapped frequentist models.
 #' @param standardize The method used for standardizing the parameters. Can be
 #'   `NULL` (default; no standardization), `"refit"` (for re-fitting the model
 #'   on standardized data) or one of `"basic"`, `"posthoc"`, `"smart"`,
-#'   `"pseudo"`. See 'Details' in [effectsize::standardize_parameters()].
-#'   **Important:**
-#'   - The `"refit"` method does *not* standardized categorical predictors (i.e.
+#'   `"pseudo"`. See 'Details' in [`standardize_parameters()`].
+#'   **Importantly**:
+#'   - The `"refit"` method does *not* standardize categorical predictors (i.e.
 #'   factors), which may be a different behaviour compared to other R packages
-#'   (such as \pkg{lm.beta}) or other software packages (like SPSS). to mimic
+#'   (such as **lm.beta**) or other software packages (like SPSS). to mimic
 #'   such behaviours, either use `standardize="basic"` or standardize the data
 #'   with `datawizard::standardize(force=TRUE)` *before* fitting the model.
 #'   - For mixed models, when using methods other than `"refit"`, only the fixed
-#'   effects will be returned.
-#'   - Robust estimation (i.e. `robust=TRUE`) of standardized parameters only
-#'   works when `standardize="refit"`.
+#'   effects will be standardized.
+#'   - Robust estimation (i.e., `vcov` set to a value other than `NULL`) of
+#'   standardized parameters only works when `standardize="refit"`.
 #' @param exponentiate Logical, indicating whether or not to exponentiate the
-#'   the coefficients (and related confidence intervals). This is typical for
-#'   logistic regression, or more generally speaking, for models with log
-#'   or logit links. **Note:** Delta-method standard errors are also
-#'   computed (by multiplying the standard errors by the transformed
-#'   coefficients). This is to mimic behaviour of other software packages, such
-#'   as Stata, but these standard errors poorly estimate uncertainty for the
-#'   transformed coefficient. The transformed confidence interval more clearly
-#'   captures this uncertainty. For `compare_parameters()`,
-#'   `exponentiate = "nongaussian"` will only exponentiate coefficients
-#'   from non-Gaussian families.
-#' @param robust Logical, if `TRUE`, robust standard errors are calculated
-#'   (if possible), and confidence intervals and p-values are based on these
-#'   robust standard errors. Additional arguments like `vcov_estimation` or
-#'   `vcov_type` are passed down to other methods, see
-#'   [`standard_error_robust()`][standard_error_robust] for details
-#'   and [this vignette](https://easystats.github.io/parameters/articles/model_parameters_robust.html)
-#'   for working examples.
-#' @param component Model component for which parameters should be shown. May be
-#'   one of `"conditional"`, `"precision"` (\pkg{betareg}),
-#'   `"scale"` (\pkg{ordinal}), `"extra"` (\pkg{glmx}),
-#'   `"marginal"` (\pkg{mfx}), `"conditional"` or `"full"` (for
-#'   `MuMIn::model.avg()`) or `"all"`.
+#'   coefficients (and related confidence intervals). This is typical for
+#'   logistic regression, or more generally speaking, for models with log or
+#'   logit links. It is also recommended to use `exponentiate = TRUE` for models
+#'   with log-transformed response values. **Note:** Delta-method standard
+#'   errors are also computed (by multiplying the standard errors by the
+#'   transformed coefficients). This is to mimic behaviour of other software
+#'   packages, such as Stata, but these standard errors poorly estimate
+#'   uncertainty for the transformed coefficient. The transformed confidence
+#'   interval more clearly captures this uncertainty. For `compare_parameters()`,
+#'   `exponentiate = "nongaussian"` will only exponentiate coefficients from
+#'   non-Gaussian families.
 #' @param p_adjust Character vector, if not `NULL`, indicates the method to
-#'   adjust p-values. See [stats::p.adjust()] for details. Further
+#'   adjust p-values. See [`stats::p.adjust()`] for details. Further
 #'   possible adjustment methods are `"tukey"`, `"scheffe"`,
 #'   `"sidak"` and `"none"` to explicitly disable adjustment for
-#'   `emmGrid` objects (from \pkg{emmeans}).
+#'   `emmGrid` objects (from **emmeans**).
 #' @param ci_method Method for computing degrees of freedom for
 #'   confidence intervals (CI) and the related p-values. Allowed are following
 #'   options (which vary depending on the model class): `"residual"`,
@@ -356,11 +372,10 @@ parameters <- model_parameters
 #'   _Confidence intervals and approximation of degrees of freedom_ in
 #'   [`model_parameters()`] for further details. When `ci_method=NULL`, in most
 #'   cases `"wald"` is used then.
-#' @param df_method Deprecated. Please use `ci_method`.
 #' @param summary Logical, if `TRUE`, prints summary information about the
 #'   model (model formula, number of observations, residual standard deviation
 #'   and more).
-#' @param keep,drop Character containing a regular expression pattern that
+#' @param keep Character containing a regular expression pattern that
 #'   describes the parameters that should be included (for `keep`) or excluded
 #'   (for `drop`) in the returned data frame. `keep` may also be a
 #'   named list of regular expressions. All non-matching parameters will be
@@ -379,14 +394,14 @@ parameters <- model_parameters
 #'   frame, which can be different from how they are printed. Inspect the
 #'   `$Parameter` column of the parameters table to get the exact parameter
 #'   names.
-#' @param parameters Deprecated, alias for `keep`.
-#' @param verbose Toggle warnings and messages.
 #' @param ... Arguments passed to or from other methods. For instance, when
 #'   `bootstrap = TRUE`, arguments like `type` or `parallel` are
-#'   passed down to `bootstrap_model()`, and arguments like `ci_method`
-#'   are passed down to [bayestestR::describe_posterior()].
+#'   passed down to `bootstrap_model()`.
+#' @param drop See `keep`.
+#' @param verbose Toggle warnings and messages.
+#' @inheritParams standard_error
 #'
-#' @seealso [insight::standardize_names()] to
+#' @seealso [`insight::standardize_names()`] to
 #'   rename columns into a consistent, standardized naming scheme.
 #'
 #' @inheritSection model_parameters Confidence intervals and approximation of degrees of freedom
@@ -398,11 +413,23 @@ parameters <- model_parameters
 #' model_parameters(model)
 #'
 #' # bootstrapped parameters
-#' model_parameters(model, bootstrap = TRUE)
+#' if (require("boot", quietly = TRUE)) {
+#'   model_parameters(model, bootstrap = TRUE)
+#' }
 #'
 #' # standardized parameters
 #' model_parameters(model, standardize = "refit")
 #'
+#' # robust, heteroskedasticity-consistent standard errors
+#' if (require("sandwich") && require("clubSandwich")) {
+#'   model_parameters(model, vcov = "HC3")
+#'
+#'   model_parameters(model,
+#'     vcov = "vcovCL",
+#'     vcov_args = list(cluster = mtcars$cyl)
+#'   )
+#' }
+#'
 #' # different p-value style in output
 #' model_parameters(model, p_digits = 5)
 #' model_parameters(model, digits = 3, ci_digits = 4, p_digits = "scientific")
@@ -417,20 +444,33 @@ parameters <- model_parameters
 #' @return A data frame of indices related to the model's parameters.
 #' @export
 model_parameters.default <- function(model,
-                                     ci = .95,
+                                     ci = 0.95,
                                      ci_method = NULL,
                                      bootstrap = FALSE,
                                      iterations = 1000,
                                      standardize = NULL,
                                      exponentiate = FALSE,
-                                     robust = FALSE,
                                      p_adjust = NULL,
-                                     summary = FALSE,
+                                     summary = getOption("parameters_summary", FALSE),
                                      keep = NULL,
                                      drop = NULL,
-                                     parameters = keep,
                                      verbose = TRUE,
+                                     vcov = NULL,
+                                     vcov_args = NULL,
                                      ...) {
+  # sanity check for inputs
+  .is_model_valid(model)
+
+  # sanity check, warn if unsupported argument is used.
+  # unsupported arguments will be removed from the argument list.
+  dots <- .check_dots(
+    dots = list(...),
+    not_allowed = c("include_sigma", "wb_component"),
+    class(model)[1],
+    verbose = FALSE
+  )
+
+  # extract model parameters table, as data frame
   out <- tryCatch(
     {
       .model_parameters_generic(
@@ -442,11 +482,12 @@ model_parameters.default <- function(model,
         merge_by = "Parameter",
         standardize = standardize,
         exponentiate = exponentiate,
-        robust = robust,
         p_adjust = p_adjust,
         summary = summary,
         keep_parameters = keep,
         drop_parameters = drop,
+        vcov = vcov,
+        vcov_args = vcov_args,
         verbose = verbose,
         ...
       )
@@ -458,23 +499,39 @@ model_parameters.default <- function(model,
     }
   )
 
+  # tell user if something went wrong...
   if (length(out) == 1 && isTRUE(is.na(out))) {
-    msg <- insight::format_message(
-      paste0("Sorry, `model_parameters()` failed with the following error (possible class '", class(model)[1], "' not supported):\n"),
+    insight::format_error(
+      paste0(
+        "Sorry, `model_parameters()` failed with the following error (possible class `",
+        class(model)[1],
+        "` not supported):\n"
+      ),
       attr(out, "error")
     )
-    stop(msg, call. = FALSE)
   } else if (is.null(out)) {
-    stop(paste0("Sorry, `model_parameters()` does currently not work for objects of class '", class(model)[1], "'."), call. = FALSE)
+    insight::format_error(
+      paste0(
+        "Sorry, `model_parameters()` does not currently work for objects of class `",
+        class(model)[1],
+        "`."
+      )
+    )
   }
 
-  attr(out, "object_name") <- deparse(substitute(model), width.cutoff = 500)
+  attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(model))
   out
 }
 
 
+
+
+# helper function for the composition of the parameters table,
+# including a bunch of attributes required for further processing
+# (like printing etc.)
+
 .model_parameters_generic <- function(model,
-                                      ci = .95,
+                                      ci = 0.95,
                                       bootstrap = FALSE,
                                       iterations = 1000,
                                       merge_by = "Parameter",
@@ -482,63 +539,71 @@ model_parameters.default <- function(model,
                                       exponentiate = FALSE,
                                       effects = "fixed",
                                       component = "conditional",
-                                      robust = FALSE,
                                       ci_method = NULL,
                                       p_adjust = NULL,
                                       summary = FALSE,
                                       keep_parameters = NULL,
                                       drop_parameters = NULL,
                                       verbose = TRUE,
-                                      df_method = ci_method,
+                                      vcov = NULL,
+                                      vcov_args = NULL,
                                       ...) {
+  dots <- list(...)
 
-  ## TODO remove later
-  if (!missing(df_method) && !identical(ci_method, df_method)) {
-    warning(insight::format_message("Argument 'df_method' is deprecated. Please use 'ci_method' instead."), call. = FALSE)
-    ci_method <- df_method
-  }
+  # ==== 1. first step, extracting (bootstrapped) model parameters -------
 
-  # Processing
+  # Processing, bootstrapped parameters
   if (bootstrap) {
     # set default method for bootstrapped CI
     if (is.null(ci_method) || missing(ci_method)) {
       ci_method <- "quantile"
     }
 
-    params <- bootstrap_parameters(
+    args <- list(
       model,
       iterations = iterations,
       ci = ci,
-      ci_method = ci_method,
-      ...
+      ci_method = ci_method
     )
+    args <- c(args, dots)
+    params <- do.call("bootstrap_parameters", args)
+
+    # Processing, non-bootstrapped parameters
   } else {
     # set default method for CI
     if (is.null(ci_method) || missing(ci_method)) {
       ci_method <- "wald"
     }
 
-    params <- .extract_parameters_generic(
+    args <- list(
       model,
       ci = ci,
       component = component,
       merge_by = merge_by,
       standardize = standardize,
       effects = effects,
-      robust = robust,
       ci_method = ci_method,
       p_adjust = p_adjust,
       keep_parameters = keep_parameters,
       drop_parameters = drop_parameters,
       verbose = verbose,
-      ...
+      vcov = vcov,
+      vcov_args = vcov_args
     )
+    args <- c(args, dots)
+    params <- do.call(".extract_parameters_generic", args)
   }
 
-  if (isTRUE(exponentiate) || identical(exponentiate, "nongaussian")) {
-    params <- .exponentiate_parameters(params, model, exponentiate)
-  }
 
+  # ==== 2. second step, exponentiate -------
+
+  # exponentiate coefficients and SE/CI, if requested
+  params <- .exponentiate_parameters(params, model, exponentiate)
+
+
+  # ==== 3. third step, add information as attributes -------
+
+  # add further information as attributes
   params <- .add_model_parameters_attributes(
     params,
     model,
@@ -548,7 +613,6 @@ model_parameters.default <- function(model,
     iterations,
     ci_method = ci_method,
     p_adjust = p_adjust,
-    robust = robust,
     summary = summary,
     verbose = verbose,
     ...
@@ -567,35 +631,34 @@ model_parameters.default <- function(model,
 #' @rdname model_parameters.default
 #' @export
 model_parameters.glm <- function(model,
-                                 ci = .95,
+                                 ci = 0.95,
                                  ci_method = NULL,
                                  bootstrap = FALSE,
                                  iterations = 1000,
                                  standardize = NULL,
                                  exponentiate = FALSE,
-                                 robust = FALSE,
                                  p_adjust = NULL,
-                                 summary = FALSE,
+                                 summary = getOption("parameters_summary", FALSE),
+                                 vcov = NULL,
+                                 vcov_args = NULL,
                                  verbose = TRUE,
-                                 df_method = ci_method,
                                  ...) {
+  dots <- list(...)
 
   # set default
   if (is.null(ci_method)) {
     ci_method <- ifelse(isTRUE(bootstrap), "quantile", "profile")
   }
 
-  ## TODO remove later
-  if (!missing(df_method) && !identical(ci_method, df_method)) {
-    warning(insight::format_message("Argument 'df_method' is deprecated. Please use 'ci_method' instead."), call. = FALSE)
-    ci_method <- df_method
-  }
-
+  # profiled CIs may take a long time to compute, so we warn the user about it
   if (insight::n_obs(model) > 1e4 && identical(ci_method, "profile")) {
-    message(insight::format_message("Profiled confidence intervals may take longer time to compute. Use 'ci_method=\"wald\"' for faster computation of CIs."))
+    insight::format_alert(
+      "Profiled confidence intervals may take longer time to compute.",
+      "Use `ci_method=\"wald\"` for faster computation of CIs."
+    )
   }
 
-  out <- .model_parameters_generic(
+  args <- list(
     model = model,
     ci = ci,
     ci_method = ci_method,
@@ -604,12 +667,17 @@ model_parameters.glm <- function(model,
     merge_by = "Parameter",
     standardize = standardize,
     exponentiate = exponentiate,
-    robust = robust,
     p_adjust = p_adjust,
     summary = summary,
-    ...
+    vcov = vcov,
+    vcov_args = vcov_args
   )
+  args <- c(args, dots)
+  out <- do.call(".model_parameters_generic", args)
 
-  attr(out, "object_name") <- deparse(substitute(model), width.cutoff = 500)
+  attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(model))
   out
 }
+
+#' @export
+model_parameters.zoo <- model_parameters.default
