@@ -11,6 +11,8 @@
 #'   `"ordinary"`).
 #' @param parallel The type of parallel operation to be used (if any).
 #' @param n_cpus Number of processes to be used in parallel operation.
+#' @param cluster Optional cluster when `parallel = "snow"`. See `?lme4::bootMer`
+#' for details.
 #' @param ... Arguments passed to or from other methods.
 #' @inheritParams p_value
 #'
@@ -29,14 +31,14 @@
 #' slopes, etc. and their confidence intervals. These can then be passed to
 #' `model_parameter()` to obtain standard errors, p-values, etc. (see
 #' example).
-#' \cr\cr
+#'
 #' Note that that p-values returned here are estimated under the assumption of
 #' *translation equivariance*: that shape of the sampling distribution is
 #' unaffected by the null being true or not. If this assumption does not hold,
 #' p-values can be biased, and it is suggested to use proper permutation tests
 #' to obtain non-parametric p-values.
 #'
-#' @seealso [bootstrap_parameters()], [simulate_model()], [simulate_parameters()]
+#' @seealso [`bootstrap_parameters()`], [`simulate_model()`], [`simulate_parameters()`]
 #'
 #' @examples
 #' \dontrun{
@@ -72,12 +74,15 @@ bootstrap_model.default <- function(model,
                                     n_cpus = 1,
                                     verbose = FALSE,
                                     ...) {
+  # check for valid input
+  .is_model_valid(model)
+
   insight::check_if_installed("boot")
 
   type <- match.arg(type, choices = c("ordinary", "parametric", "balanced", "permutation", "antithetic"))
   parallel <- match.arg(parallel)
 
-  model_data <- data <- insight::get_data(model)
+  model_data <- data <- insight::get_data(model, verbose = FALSE)
   model_response <- insight::find_response(model)
 
   boot_function <- function(model, data, indices) {
@@ -152,6 +157,7 @@ bootstrap_model.merMod <- function(model,
                                    type = "parametric",
                                    parallel = c("no", "multicore", "snow"),
                                    n_cpus = 1,
+                                   cluster = NULL,
                                    verbose = FALSE,
                                    ...) {
   insight::check_if_installed("lme4")
@@ -163,6 +169,16 @@ bootstrap_model.merMod <- function(model,
     params <- insight::get_parameters(model, verbose = FALSE)
     n_params <- insight::n_parameters(model)
 
+    # for glmmTMB, remove dispersion paramters, if any
+    if (inherits(model, "glmmTMB") && "Component" %in% names(params) && "dispersion" %in% params$Component) {
+      # find number of dispersion parameters
+      n_disp <- sum(params$Component == "dispersion")
+      # remove dispersion parameters
+      params <- params[params$Component != "dispersion", ]
+      # make sure number of parameters is updated
+      n_params <- n_params - n_disp
+    }
+
     if (nrow(params) != n_params) {
       params <- stats::setNames(rep.int(NA, n_params), params$Parameter)
     } else {
@@ -178,7 +194,8 @@ bootstrap_model.merMod <- function(model,
       nsim = iterations,
       type = type,
       parallel = parallel,
-      ncpus = n_cpus
+      ncpus = n_cpus,
+      cl = cluster
     )
   } else {
     results <- suppressMessages(lme4::bootMer(
@@ -188,7 +205,8 @@ bootstrap_model.merMod <- function(model,
       verbose = FALSE,
       type = type,
       parallel = parallel,
-      ncpus = n_cpus
+      ncpus = n_cpus,
+      cl = cluster
     ))
   }
 
