@@ -1,8 +1,8 @@
 #' @rdname p_value_ml1
 #' @export
 dof_ml1 <- function(model) {
-  if (!insight::model_info(model, verbose = FALSE)$is_mixed) {
-    stop("Model must be a mixed model.")
+  if (!insight::is_mixed_model(model)) {
+    stop("Model must be a mixed model.", call. = FALSE)
   }
 
   re_groups <- insight::get_random(model)
@@ -17,7 +17,7 @@ dof_ml1 <- function(model) {
   term_assignment <- .find_term_assignment(model_data, predictors, parameters)
 
   ddf <- sapply(model_data, function(.x) {
-    min(sapply(re_groups, .get_df_ml1_approx, x = .x))
+    min(vapply(re_groups, .get_df_ml1_approx, numeric(1), x = .x))
   })
 
   ltab <- table(ddf)
@@ -30,8 +30,8 @@ dof_ml1 <- function(model) {
   ddf[] <- ltab$ddf[ii]
 
   out <- numeric(length = length(parameters))
-  ## TODO number of items to replace is not a multiple of replacement length
-  suppressWarnings(out[which("(Intercept)" != parameters)] <- ddf[term_assignment])
+  ## FIXME: number of items to replace is not a multiple of replacement length
+  suppressWarnings(out[which("(Intercept)" != parameters)] <- ddf[term_assignment]) # nolint
   if (has_intcp) out[which("(Intercept)" == parameters)] <- min(ddf)
 
   stats::setNames(out, parameters)
@@ -65,16 +65,17 @@ dof_ml1 <- function(model) {
 
 
 .find_term_assignment <- function(model_data, predictors, parameters) {
-  parms <- unlist(lapply(1:length(predictors), function(i) {
+  parms <- unlist(lapply(seq_along(predictors), function(i) {
     p <- predictors[i]
     if (is.factor(model_data[[p]])) {
       ps <- paste0(p, levels(model_data[[p]]))
-      names(ps)[1:length(ps)] <- i
+      names(ps)[seq_along(ps)] <- i
       ps
     } else {
       names(p) <- i
       p
     }
   }))
-  stats::na.omit(as.numeric(names(parms)[match(insight::clean_names(parameters), parms)]))
+  out <- as.numeric(names(parms)[match(insight::clean_names(parameters), parms)])
+  out[!is.na(out)]
 }
