@@ -1,4 +1,3 @@
-#' @importFrom stats setNames
 #' @rdname p_value_satterthwaite
 #' @export
 dof_satterthwaite <- function(model) {
@@ -8,11 +7,9 @@ dof_satterthwaite <- function(model) {
 
 #' @export
 dof_satterthwaite.lmerMod <- function(model) {
-  if (!requireNamespace("lmerTest", quietly = TRUE)) {
-    stop("Package `lmerTest` required for Satterthwaite approximation. Please install it.", call. = FALSE)
-  }
+  insight::check_if_installed("lmerTest")
 
-  parameters <- find_parameters(model, effects = "fixed", flatten = TRUE)
+  parameters <- insight::find_parameters(model, effects = "fixed", flatten = TRUE)
   lmerTest_model <- lmerTest::as_lmerModLmerTest(model)
   s <- summary(lmerTest_model)
 
@@ -22,10 +19,9 @@ dof_satterthwaite.lmerMod <- function(model) {
 
 #' @export
 dof_satterthwaite.lme <- function(model) {
-  if (!requireNamespace("lavaSearch2", quietly = TRUE)) {
-    stop("Package `lavaSearch2` required for Satterthwaite approximation. Please install it.", call. = FALSE)
-  }
-  parameters <- find_parameters(model, effects = "fixed", flatten = TRUE)
+  insight::check_if_installed("lavaSearch2")
+
+  parameters <- insight::find_parameters(model, effects = "fixed", flatten = TRUE)
   lavaSearch2::sCorrect(model) <- TRUE
   s <- lavaSearch2::summary2(model)
   stats::setNames(as.vector(s$tTable[, "df"]), parameters)
