@@ -44,100 +44,97 @@ bayestestR::equivalence_test
 #' interpretation of the p-value may differ from the results returned from
 #' the equivalence test.
 #'
-#' \subsection{Calculation of equivalence testing}{
-#'   \describe{
-#'     \item{"bayes" - Bayesian rule (Kruschke 2018)}{
-#'       This rule follows the \dQuote{HDI+ROPE decision rule} \cite{(Kruschke,
-#'       2014, 2018)} used for the
-#'       [`Bayesian counterpart()`][bayestestR::equivalence_test]. This
-#'       means, if the confidence intervals are completely outside the ROPE, the
-#'       "null hypothesis" for this parameter is "rejected". If the ROPE
-#'       completely covers the CI, the null hypothesis is accepted. Else, it's
-#'       undecided whether to accept or reject the null hypothesis. Desirable
-#'       results are low proportions inside the ROPE (the closer to zero the
-#'       better).
-#'     }
-#'     \item{"classic" - The TOST rule (Lakens 2017)}{
-#'       This rule follows the \dQuote{TOST rule}, i.e. a two one-sided test
-#'       procedure (\cite{Lakens 2017}). Following this rule, practical
-#'       equivalence of an effect (i.e. H0) is *rejected*, when the
-#'       coefficient is statistically significant *and* the narrow
-#'       confidence intervals (i.e. `1-2*alpha`) *include* or
-#'       *exceed* the ROPE boundaries. Practical equivalence is assumed
-#'       (i.e. H0 accepted) when the narrow confidence intervals are completely
-#'       inside the ROPE, no matter if the effect is statistically significant
-#'       or not. Else, the decision whether to accept or reject H0 is undecided.
-#'     }
-#'     \item{"cet" - Conditional Equivalence Testing (Campbell/Gustafson 2018)}{
-#'     The Conditional Equivalence Testing as described by \cite{Campbell and
-#'     Gustafson 2018}. According to this rule, practical equivalence is
-#'     rejected when the coefficient is statistically significant. When the
-#'     effect is *not* significant and the narrow confidence intervals are
-#'     completely inside the ROPE, we accept H0, else it is undecided.
-#'     }
-#'   }
-#' }
-#' \subsection{Levels of Confidence Intervals used for Equivalence Testing}{
-#'   For `rule = "classic"`, "narrow" confidence intervals are used for
-#'   equivalence testing. "Narrow" means, the the intervals is not 1 - alpha,
-#'   but 1 - 2 * alpha. Thus, if `ci = .95`, alpha is assumed to be 0.05
-#'   and internally a ci-level of 0.90 is used. `rule = "cet"` uses
-#'   both regular and narrow confidence intervals, while `rule = "bayes"`
-#'   only uses the regular intervals.
-#' }
-#' \subsection{p-Values}{
-#'   The equivalence p-value is the area of the (cumulative) confidence
-#'   distribution that is outside of the region of equivalence. It can be
-#'   interpreted as p-value for *rejecting* the alternative hypothesis
-#'   and *accepting* the null hypothesis.
-#' }
-#' \subsection{Second Generation p-Value (SGPV)}{
-#'   Second generation p-values (SGPV) were proposed as a statistic
-#'   that represents \dQuote{the proportion of data-supported hypotheses
-#'   that are also null hypotheses} \cite{(Blume et al. 2018)}. This statistic
-#'   is actually computed in the same way as the percentage inside the ROPE as
-#'   returned by `equivalence_test()` (see \cite{Lakens and Delacre 2020}
-#'   for details on computation of the SGPV). Thus, the `"inside ROPE"`
-#'   column reflects the SGPV.
-#' }
-#' \subsection{ROPE range}{
-#'   Some attention is required for finding suitable values for the ROPE limits
-#'   (argument `range`). See 'Details' in [bayestestR::rope_range()]
-#'   for further information.
-#' }
+#' ## Calculation of equivalence testing
+#' - "bayes" - Bayesian rule (Kruschke 2018)
 #'
-#' @note There is also a [`plot()`-method](https://easystats.github.io/see/articles/parameters.html) implemented in the \href{https://easystats.github.io/see/}{\pkg{see}-package}.
+#'   This rule follows the \dQuote{HDI+ROPE decision rule} \cite{(Kruschke,
+#'   2014, 2018)} used for the
+#'   [`Bayesian counterpart()`][bayestestR::equivalence_test]. This
+#'   means, if the confidence intervals are completely outside the ROPE, the
+#'   "null hypothesis" for this parameter is "rejected". If the ROPE
+#'   completely covers the CI, the null hypothesis is accepted. Else, it's
+#'   undecided whether to accept or reject the null hypothesis. Desirable
+#'   results are low proportions inside the ROPE (the closer to zero the
+#'   better).
+#'
+#' - "classic" - The TOST rule (Lakens 2017)
+#'
+#'   This rule follows the "TOST rule", i.e. a two one-sided test procedure
+#'   (_Lakens 2017_). Following this rule, practical equivalence of an effect
+#'   (i.e. H0) is *rejected*, when the coefficient is statistically significant
+#'   *and* the narrow confidence intervals (i.e. `1-2*alpha`) *include* or
+#'   *exceed* the ROPE boundaries. Practical equivalence is assumed
+#'   (i.e. H0 accepted) when the narrow confidence intervals are completely
+#'   inside the ROPE, no matter if the effect is statistically significant
+#'   or not. Else, the decision whether to accept or reject H0 is undecided.
+#'
+#' - "cet" - Conditional Equivalence Testing (Campbell/Gustafson 2018)
+#'
+#'   The Conditional Equivalence Testing as described by _Campbell and
+#'   Gustafson 2018_. According to this rule, practical equivalence is
+#'   rejected when the coefficient is statistically significant. When the
+#'   effect is *not* significant and the narrow confidence intervals are
+#'   completely inside the ROPE, we accept H0, else it is undecided.
+#'
+#' ## Levels of Confidence Intervals used for Equivalence Testing
+#' For `rule = "classic"`, "narrow" confidence intervals are used for
+#' equivalence testing. "Narrow" means, the the intervals is not 1 - alpha,
+#' but 1 - 2 * alpha. Thus, if `ci = .95`, alpha is assumed to be 0.05
+#' and internally a ci-level of 0.90 is used. `rule = "cet"` uses
+#' both regular and narrow confidence intervals, while `rule = "bayes"`
+#' only uses the regular intervals.
+#'
+#' ## p-Values
+#' The equivalence p-value is the area of the (cumulative) confidence
+#' distribution that is outside of the region of equivalence. It can be
+#' interpreted as p-value for *rejecting* the alternative hypothesis
+#' and *accepting* the null hypothesis.
+#'
+#' ## Second Generation p-Value (SGPV)
+#' Second generation p-values (SGPV) were proposed as a statistic that
+#' represents _the proportion of data-supported hypotheses that are also null
+#' hypotheses_ _(Blume et al. 2018)_. This statistic is actually computed in
+#' the same way as the percentage inside the ROPE as returned by
+#' `equivalence_test()` (see _Lakens and Delacre 2020_ for details on
+#' computation of the SGPV). Thus, the `"inside ROPE"` column reflects the SGPV.
+#'
+#' ## ROPE range
+#' Some attention is required for finding suitable values for the ROPE limits
+#' (argument `range`). See 'Details' in [bayestestR::rope_range()]
+#' for further information.
+#'
+#' @note There is also a [`plot()`-method](https://easystats.github.io/see/articles/parameters.html)
+#' implemented in the [**see**-package](https://easystats.github.io/see/).
 #'
 #' @references
-#' \itemize{
-#'   \item Blume, J. D., D'Agostino McGowan, L., Dupont, W. D., & Greevy, R. A.
+#'
+#'   - Blume, J. D., D'Agostino McGowan, L., Dupont, W. D., & Greevy, R. A.
 #'   (2018). Second-generation p-values: Improved rigor, reproducibility, &
 #'   transparency in statistical analyses. PLOS ONE, 13(3), e0188299.
 #'   https://doi.org/10.1371/journal.pone.0188299
 #'
-#'   \item Campbell, H., & Gustafson, P. (2018). Conditional equivalence
+#'   - Campbell, H., & Gustafson, P. (2018). Conditional equivalence
 #'   testing: An alternative remedy for publication bias. PLOS ONE, 13(4),
 #'   e0195145. doi: 10.1371/journal.pone.0195145
 #'
-#'   \item Kruschke, J. K. (2014). Doing Bayesian data analysis: A tutorial with
+#'   - Kruschke, J. K. (2014). Doing Bayesian data analysis: A tutorial with
 #'   R, JAGS, and Stan. Academic Press
 #'
-#'   \item Kruschke, J. K. (2018). Rejecting or accepting parameter values in
+#'   - Kruschke, J. K. (2018). Rejecting or accepting parameter values in
 #'   Bayesian estimation. Advances in Methods and Practices in Psychological
 #'   Science, 1(2), 270-280. doi: 10.1177/2515245918771304
 #'
-#'   \item Lakens, D. (2017). Equivalence Tests: A Practical Primer for t Tests,
+#'   - Lakens, D. (2017). Equivalence Tests: A Practical Primer for t Tests,
 #'   Correlations, and Meta-Analyses. Social Psychological and Personality
 #'   Science, 8(4), 355–362. doi: 10.1177/1948550617697177
 #'
-#'   \item Lakens, D., & Delacre, M. (2020). Equivalence Testing and the Second
+#'   - Lakens, D., & Delacre, M. (2020). Equivalence Testing and the Second
 #'   Generation P-Value. Meta-Psychology, 4.
 #'   https://doi.org/10.15626/MP.2018.933
 #'
-#'   \item Pernet, C. (2017). Null hypothesis significance testing: A guide to
+#'   - Pernet, C. (2017). Null hypothesis significance testing: A guide to
 #'   commonly misunderstood concepts and recommendations for good practice.
 #'   F1000Research, 4, 621. doi: 10.12688/f1000research.6963.5
-#' }
 #'
 #' @return A data frame.
 #' @examples
@@ -158,7 +155,7 @@ bayestestR::equivalence_test
 #' @export
 equivalence_test.lm <- function(x,
                                 range = "default",
-                                ci = .95,
+                                ci = 0.95,
                                 rule = "classic",
                                 verbose = TRUE,
                                 ...) {
@@ -168,7 +165,7 @@ equivalence_test.lm <- function(x,
   if (is.null(attr(out, "pretty_names", exact = TRUE))) {
     attr(out, "pretty_names") <- format_parameters(x)
   }
-  attr(out, "object_name") <- .safe_deparse(substitute(x))
+  attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(x))
   attr(out, "rule") <- rule
   class(out) <- c("equivalence_test_lm", "see_equivalence_test_lm", class(out))
   out
@@ -221,12 +218,11 @@ equivalence_test.rma <- equivalence_test.lm
 #' @export
 equivalence_test.merMod <- function(x,
                                     range = "default",
-                                    ci = .95,
+                                    ci = 0.95,
                                     rule = "classic",
                                     effects = c("fixed", "random"),
                                     verbose = TRUE,
                                     ...) {
-
   # ==== argument matching ====
 
   rule <- match.arg(tolower(rule), choices = c("bayes", "classic", "cet"))
@@ -247,7 +243,7 @@ equivalence_test.merMod <- function(x,
   if (is.null(attr(out, "pretty_names", exact = TRUE))) {
     attr(out, "pretty_names") <- format_parameters(x)
   }
-  attr(out, "object_name") <- .safe_deparse(substitute(x))
+  attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(x))
   attr(out, "rule") <- rule
   class(out) <- c("equivalence_test_lm", "see_equivalence_test_lm", class(out))
   out
@@ -267,18 +263,19 @@ equivalence_test.MixMod <- equivalence_test.merMod
 #' @export
 equivalence_test.parameters_simulate_model <- function(x,
                                                        range = "default",
-                                                       ci = .95,
+                                                       ci = 0.95,
                                                        verbose = TRUE,
                                                        ...) {
-
   # ==== retrieve model, to define rope range for simulated model parameters ====
 
   model <- .get_object(x)
 
   if (all(range == "default") && !is.null(model)) {
     range <- bayestestR::rope_range(model, verbose = verbose)
-  } else if (!all(is.numeric(range)) | length(range) != 2) {
-    stop("`range` should be 'default' or a vector of 2 numeric values (e.g., c(-0.1, 0.1)).")
+  } else if (!all(is.numeric(range)) || length(range) != 2) {
+    insight::format_error(
+      "`range` should be \"default\" or a vector of 2 numeric values (e.g., `c(-0.1, 0.1)`)."
+    )
   }
 
 
@@ -306,11 +303,10 @@ equivalence_test.parameters_simulate_model <- function(x,
 #' @keywords internal
 .equivalence_test_frequentist <- function(x,
                                           range = "default",
-                                          ci = .95,
+                                          ci = 0.95,
                                           rule = "classic",
                                           verbose = TRUE,
                                           ...) {
-
   # ==== define rope range ====
 
   if (all(range == "default")) {
@@ -318,12 +314,14 @@ equivalence_test.parameters_simulate_model <- function(x,
     if (is.list(range)) {
       range <- range[[which.max(sapply(range, diff))]]
     }
-  } else if (!all(is.numeric(range)) | length(range) != 2) {
-    stop("`range` should be 'default' or a vector of 2 numeric values (e.g., c(-0.1, 0.1)).")
+  } else if (!all(is.numeric(range)) || length(range) != 2) {
+    insight::format_error(
+      "`range` should be \"default\" or a vector of 2 numeric values (e.g., `c(-0.1, 0.1)`)."
+    )
   }
 
   if (length(ci) > 1) {
-    warning("`ci` may only be of length 1. Using first ci-value now.", call. = FALSE)
+    insight::format_warning("`ci` may only be of length 1. Using first ci-value now.")
     ci <- ci[1]
   }
 
@@ -380,19 +378,21 @@ equivalence_test.parameters_simulate_model <- function(x,
 #' @keywords internal
 .equivalence_test_frequentist_random <- function(x,
                                                  range = "default",
-                                                 ci = .95,
+                                                 ci = 0.95,
                                                  rule = "classic",
                                                  verbose = TRUE,
                                                  ...) {
   if (all(range == "default")) {
     range <- bayestestR::rope_range(x, verbose = verbose)
-  } else if (!all(is.numeric(range)) | length(range) != 2) {
-    stop("`range` should be 'default' or a vector of 2 numeric values (e.g., c(-0.1, 0.1)).")
+  } else if (!all(is.numeric(range)) || length(range) != 2) {
+    insight::format_error(
+      "`range` should be \"default\" or a vector of 2 numeric values (e.g., `c(-0.1, 0.1)`)."
+    )
   }
 
   if (length(ci) > 1) {
     if (isTRUE(verbose)) {
-      warning("`ci` may only be of length 1. Using first ci-value now.", call. = FALSE)
+      insight::format_warning("`ci` may only be of length 1. Using first ci-value now.")
     }
     ci <- ci[1]
   }
@@ -601,7 +601,6 @@ format.equivalence_test_lm <- function(x,
                                        format = "text",
                                        zap_small = FALSE,
                                        ...) {
-
   # default brackets are parenthesis for HTML / MD
   if ((is.null(ci_brackets) || isTRUE(ci_brackets)) && (identical(format, "html") || identical(format, "markdown"))) {
     ci_brackets <- c("(", ")")
