@@ -3,7 +3,7 @@
 #' @rdname model_parameters.averaging
 #' @export
 model_parameters.betareg <- function(model,
-                                     ci = .95,
+                                     ci = 0.95,
                                      bootstrap = FALSE,
                                      iterations = 1000,
                                      component = c("conditional", "precision", "all"),
@@ -12,6 +12,14 @@ model_parameters.betareg <- function(model,
                                      p_adjust = NULL,
                                      verbose = TRUE,
                                      ...) {
+  # sanity check, warn if unsupported argument is used.
+  dot_args <- .check_dots(
+    dots = list(...),
+    not_allowed = c("vcov", "vcov_args"),
+    class(model)[1],
+    verbose = verbose
+  )
+
   component <- match.arg(component)
   if (component == "all") {
     merge_by <- c("Parameter", "Component")
@@ -21,8 +29,8 @@ model_parameters.betareg <- function(model,
 
   ## TODO check merge by
 
-  out <- .model_parameters_generic(
-    model = model,
+  args <- list(
+    model,
     ci = ci,
     component = component,
     bootstrap = bootstrap,
@@ -31,30 +39,52 @@ model_parameters.betareg <- function(model,
     standardize = standardize,
     exponentiate = exponentiate,
     p_adjust = p_adjust,
-    ...
+    vcov = NULL,
+    vcov_args = NULL
   )
+  args <- c(args, dot_args)
 
-  attr(out, "object_name") <- deparse(substitute(model), width.cutoff = 500)
+  out <- do.call(".model_parameters_generic", args)
+  attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(model))
   out
 }
 
 
 #' @export
 ci.betareg <- function(x,
-                       ci = .95,
+                       ci = 0.95,
                        component = "all",
+                       verbose = TRUE,
                        ...) {
+  # sanity check, warn if unsupported argument is used.
+  dot_args <- .check_dots(
+    dots = list(...),
+    not_allowed = c("vcov", "vcov_args"),
+    class(x)[1],
+    function_name = "ci",
+    verbose = verbose
+  )
+
   component <- match.arg(component, choices = c("all", "conditional", "precision"))
-  .ci_generic(model = x, ci = ci, dof = Inf, component = component)
+  .ci_generic(model = x, ci = ci, dof = Inf, component = component, verbose = verbose)
 }
 
 
-#' @rdname standard_error
 #' @export
 standard_error.betareg <- function(model,
-                                   component = c("all", "conditional", "precision"),
+                                   component = "all",
+                                   verbose = TRUE,
                                    ...) {
-  component <- match.arg(component)
+  # sanity check, warn if unsupported argument is used.
+  dot_args <- .check_dots(
+    dots = list(...),
+    not_allowed = c("vcov", "vcov_args"),
+    class(model)[1],
+    function_name = "standard_error",
+    verbose = verbose
+  )
+
+  component <- match.arg(component, choices = c("all", "conditional", "precision"))
 
   params <- insight::get_parameters(model)
   cs <- do.call(rbind, stats::coef(summary(model)))
@@ -78,7 +108,17 @@ standard_error.betareg <- function(model,
 #' @export
 p_value.betareg <- function(model,
                             component = c("all", "conditional", "precision"),
+                            verbose = TRUE,
                             ...) {
+  # sanity check, warn if unsupported argument is used.
+  dot_args <- .check_dots(
+    dots = list(...),
+    not_allowed = c("vcov", "vcov_args"),
+    class(model)[1],
+    function_name = "p_value",
+    verbose = verbose
+  )
+
   component <- match.arg(component)
 
   params <- insight::get_parameters(model)
@@ -105,9 +145,9 @@ simulate_model.betareg <- function(model,
                                    component = c("all", "conditional", "precision"),
                                    ...) {
   component <- match.arg(component)
-  out <- .simulate_model(model, iterations, component = component)
+  out <- .simulate_model(model, iterations, component = component, ...)
 
   class(out) <- c("parameters_simulate_model", class(out))
-  attr(out, "object_name") <- .safe_deparse(substitute(model))
+  attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(model))
   out
 }
