@@ -28,7 +28,7 @@
 #' @export
 model_parameters.dbscan <- function(model, data = NULL, clusters = NULL, ...) {
   if (is.null(data)) {
-    stop("This function requires the data used to compute the clustering to be provided via 'data' as it is not accessible from the clustering object itself.")
+    insight::format_error("This function requires the data used to compute the clustering to be provided via `data` as it is not accessible from the clustering object itself.")
   }
 
   if (is.null(clusters)) {
