@@ -3,30 +3,24 @@
 # model_parameters ----------------
 
 
+#' @rdname model_parameters.averaging
 #' @export
 model_parameters.emmGrid <- function(model,
-                                     ci = .95,
+                                     ci = 0.95,
                                      centrality = "median",
                                      dispersion = FALSE,
-                                     ci_method = "hdi",
-                                     test = c("pd", "rope"),
+                                     ci_method = "eti",
+                                     test = "pd",
                                      rope_range = "default",
                                      rope_ci = 0.95,
                                      exponentiate = FALSE,
                                      p_adjust = NULL,
-                                     parameters = NULL,
+                                     keep = NULL,
+                                     drop = NULL,
                                      verbose = TRUE,
                                      ...) {
-
   # set default for p-adjust
-  emm_padjust <- tryCatch(
-    {
-      adj <- model@misc$adjust
-    },
-    error = function(e) {
-      NULL
-    }
-  )
+  emm_padjust <- tryCatch(model@misc$adjust, error = function(e) NULL)
   if (!is.null(emm_padjust) && is.null(p_adjust)) {
     p_adjust <- emm_padjust
   }
@@ -36,7 +30,6 @@ model_parameters.emmGrid <- function(model,
 
   # we assume frequentist here...
   if (!.is_bayesian_emmeans(model)) {
-
     # get statistic, se and p
     statistic <- insight::get_statistic(model, ci = ci, adjust = "none")
     SE <- standard_error(model)
@@ -52,7 +45,6 @@ model_parameters.emmGrid <- function(model,
       params <- .p_adjust(params, p_adjust, model, verbose)
     }
   } else {
-
     # Bayesian models go here...
     params <- bayestestR::describe_posterior(
       model,
@@ -75,20 +67,26 @@ model_parameters.emmGrid <- function(model,
 
 
   # Renaming
+  estName <- attr(s, "estName")
   if (!is.null(statistic)) {
-    names(params) <- gsub("Statistic", gsub("-statistic", "", attr(statistic, "statistic", exact = TRUE), fixed = TRUE), names(params))
+    names(params) <- gsub(
+      "Statistic",
+      gsub("-statistic", "", attr(statistic, "statistic", exact = TRUE), fixed = TRUE),
+      names(params),
+      fixed = TRUE
+    )
   }
-  names(params) <- gsub("Std. Error", "SE", names(params))
-  names(params) <- gsub(estName <- attr(s, "estName"), "Estimate", names(params))
-  names(params) <- gsub("lower.CL", "CI_low", names(params))
-  names(params) <- gsub("upper.CL", "CI_high", names(params))
-  names(params) <- gsub("asymp.LCL", "CI_low", names(params))
-  names(params) <- gsub("asymp.UCL", "CI_high", names(params))
-  names(params) <- gsub("lower.HPD", "CI_low", names(params))
-  names(params) <- gsub("upper.HPD", "CI_high", names(params))
+  names(params) <- gsub("Std. Error", "SE", names(params), fixed = TRUE)
+  names(params) <- gsub(estName, "Estimate", names(params), fixed = TRUE)
+  names(params) <- gsub("lower.CL", "CI_low", names(params), fixed = TRUE)
+  names(params) <- gsub("upper.CL", "CI_high", names(params), fixed = TRUE)
+  names(params) <- gsub("asymp.LCL", "CI_low", names(params), fixed = TRUE)
+  names(params) <- gsub("asymp.UCL", "CI_high", names(params), fixed = TRUE)
+  names(params) <- gsub("lower.HPD", "CI_low", names(params), fixed = TRUE)
+  names(params) <- gsub("upper.HPD", "CI_high", names(params), fixed = TRUE)
 
   # check if we have CIs
-  if (!any(grepl("^CI_", colnames(params)))) {
+  if (!any(startsWith(colnames(params), "CI_"))) {
     df_column <- grep("(df|df_error)", colnames(params))
     if (length(df_column) > 0) {
       df <- params[[df_column[1]]]
@@ -116,19 +114,30 @@ model_parameters.emmGrid <- function(model,
   params <- params[order[order %in% names(params)]]
 
   # rename
-  names(params) <- gsub("Estimate", "Coefficient", names(params))
+  names(params) <- gsub("Estimate", "Coefficient", names(params), fixed = TRUE)
 
-  if (isTRUE(exponentiate) || identical(exponentiate, "nongaussian")) {
-    params <- .exponentiate_parameters(params, model, exponentiate)
-  }
+  # exponentiate coefficients and SE/CI, if requested
+  params <- .exponentiate_parameters(params, model, exponentiate)
 
   # filter parameters
-  if (!is.null(parameters)) {
-    params <- .filter_parameters(params, parameters, verbose = verbose)
+  if (!is.null(keep) || !is.null(drop)) {
+    params <- .filter_parameters(params,
+      keep = keep,
+      drop = drop,
+      verbose = verbose
+    )
   }
 
-  params <- suppressWarnings(.add_model_parameters_attributes(params, model, ci, exponentiate = FALSE, p_adjust = p_adjust, verbose = verbose, ...))
-  attr(params, "object_name") <- deparse(substitute(model), width.cutoff = 500)
+  params <- suppressWarnings(.add_model_parameters_attributes(
+    params,
+    model,
+    ci,
+    exponentiate = FALSE,
+    p_adjust = p_adjust,
+    verbose = verbose,
+    ...
+  ))
+  attr(params, "object_name") <- insight::safe_deparse_symbol(substitute(model))
   attr(params, "parameter_names") <- parameter_names
 
   class(params) <- c("parameters_model", "see_parameters_model", class(params))
@@ -136,9 +145,10 @@ model_parameters.emmGrid <- function(model,
 }
 
 
+#' @rdname model_parameters.averaging
 #' @export
 model_parameters.emm_list <- function(model,
-                                      ci = .95,
+                                      ci = 0.95,
                                       exponentiate = FALSE,
                                       p_adjust = NULL,
                                       verbose = TRUE,
@@ -162,18 +172,80 @@ model_parameters.emm_list <- function(model,
   params <- do.call(rbind, params)
   params$Component <- .pretty_emmeans_Component_names(s)
 
-  if (isTRUE(exponentiate) || identical(exponentiate, "nongaussian")) {
-    params <- .exponentiate_parameters(params, model, exponentiate)
-  }
+  # exponentiate coefficients and SE/CI, if requested
+  params <- .exponentiate_parameters(params, model, exponentiate)
+
   params <- .add_model_parameters_attributes(params, model, ci, exponentiate, p_adjust = p_adjust, verbose = verbose, ...)
 
-  attr(params, "object_name") <- deparse(substitute(model), width.cutoff = 500)
+  attr(params, "object_name") <- insight::safe_deparse_symbol(substitute(model))
   class(params) <- c("parameters_model", "see_parameters_model", class(params))
 
   params
 }
 
 
+#' @export
+model_parameters.summary_emm <- function(model,
+                                         keep = NULL,
+                                         drop = NULL,
+                                         verbose = TRUE,
+                                         ...) {
+  params <- model
+  # Renaming
+  estName <- attr(model, "estName")
+  names(params) <- gsub("Std. Error", "SE", names(params), fixed = TRUE)
+  names(params) <- gsub(estName, "Estimate", names(params), fixed = TRUE)
+  names(params) <- gsub("response", "Response", names(params), fixed = TRUE)
+  names(params) <- gsub("lower.CL", "CI_low", names(params), fixed = TRUE)
+  names(params) <- gsub("upper.CL", "CI_high", names(params), fixed = TRUE)
+  names(params) <- gsub("asymp.LCL", "CI_low", names(params), fixed = TRUE)
+  names(params) <- gsub("asymp.UCL", "CI_high", names(params), fixed = TRUE)
+  names(params) <- gsub("lower.HPD", "CI_low", names(params), fixed = TRUE)
+  names(params) <- gsub("upper.HPD", "CI_high", names(params), fixed = TRUE)
+
+  # rename if necessary
+  if ("df" %in% colnames(params)) {
+    colnames(params)[colnames(params) == "df"] <- "df_error"
+  }
+
+  # Reorder
+  estimate_pos <- which(colnames(model) == estName)
+  parameter_names <- colnames(params)[seq_len(estimate_pos - 1)]
+  order <- c(
+    parameter_names, "Estimate", "Median", "Mean", "SE", "SD", "MAD",
+    "CI_low", "CI_high", "F", "t", "z", "df", "df_error", "p", "pd",
+    "ROPE_CI", "ROPE_low", "ROPE_high", "ROPE_Percentage"
+  )
+  params <- params[order[order %in% names(params)]]
+
+  # rename
+  names(params) <- gsub("Estimate", "Coefficient", names(params), fixed = TRUE)
+
+  # filter parameters
+  if (!is.null(keep) || !is.null(drop)) {
+    params <- .filter_parameters(params,
+      keep = keep,
+      drop = drop,
+      verbose = verbose
+    )
+  }
+
+  params <- suppressWarnings(.add_model_parameters_attributes(
+    params,
+    model,
+    ci = 0.95,
+    exponentiate = FALSE,
+    p_adjust = NULL,
+    verbose = verbose,
+    ...
+  ))
+  attr(params, "object_name") <- insight::safe_deparse_symbol(substitute(model))
+  attr(params, "parameter_names") <- parameter_names
+
+  class(params) <- c("parameters_model", "see_parameters_model", class(params))
+  params
+}
+
 
 
 # standard errors -----------------
@@ -227,13 +299,14 @@ boot_em_standard_error <- function(model) {
   est <- insight::get_parameters(model, summary = FALSE)
 
   Component <- NULL
-  if (inherits(s <- summary(model), "list")) {
+  s <- summary(model)
+  if (inherits(s, "list")) {
     Component <- .pretty_emmeans_Component_names(s)
   }
 
   out <- .data_frame(
     Parameter = .pretty_emmeans_Parameter_names(model),
-    SE = sapply(est, stats::sd)
+    SE = vapply(est, stats::sd, numeric(1))
   )
 
   if (!is.null(Component)) out$Component <- Component
@@ -284,7 +357,7 @@ boot_em_df <- function(model) {
 
 #' @rdname p_value
 #' @export
-p_value.emmGrid <- function(model, ci = .95, adjust = "none", ...) {
+p_value.emmGrid <- function(model, ci = 0.95, adjust = "none", ...) {
   if (!is.null(model@misc$is_boot) && model@misc$is_boot) {
     return(boot_em_pval(model, adjust))
   }
@@ -335,7 +408,6 @@ p_value.emm_list <- function(model, adjust = "none", ...) {
 
   # any missing values?
   if (anyNA(out$p)) {
-
     # standard errors
     se <- unlist(lapply(s, function(i) {
       if (is.null(i$SE)) {
@@ -358,13 +430,12 @@ p_value.emm_list <- function(model, adjust = "none", ...) {
 
 boot_em_pval <- function(model, adjust) {
   est <- insight::get_parameters(model, summary = FALSE)
-
   p <- sapply(est, p_value)
-
   p <- stats::p.adjust(p, method = adjust)
 
   Component <- NULL
-  if (inherits(s <- summary(model), "list")) {
+  s <- summary(model)
+  if (inherits(s, "list")) {
     Component <- .pretty_emmeans_Component_names(s)
   }
 
@@ -401,7 +472,7 @@ format_parameters.emm_list <- function(model, ...) {
     params <- s[, 1:(estimate_pos - 1), drop = FALSE]
     if (ncol(params) >= 2) {
       r <- apply(params, 1, function(i) paste0(colnames(params), " [", i, "]"))
-      parnames <- unname(sapply(as.data.frame(r), paste, collapse = ", "))
+      parnames <- unname(sapply(as.data.frame(r), toString))
     } else {
       parnames <- as.vector(params[[1]])
     }
