@@ -10,7 +10,7 @@ model_parameters.gam <- model_parameters.cgam
 
 
 #' @export
-ci.gam <- function(x, ci = .95, method = NULL, ...) {
+ci.gam <- function(x, ci = 0.95, method = NULL, ...) {
   .ci_generic(model = x, ci = ci, method = "wald", ...)
 }
 
@@ -19,14 +19,25 @@ ci.gam <- function(x, ci = .95, method = NULL, ...) {
 standard_error.gam <- function(model, ...) {
   p.table <- summary(model)$p.table
   s.table <- summary(model)$s.table
-  n_cond <- nrow(p.table)
-  n_smooth <- nrow(s.table)
+  d1 <- d2 <- NULL
 
-  .data_frame(
-    Parameter = .remove_backticks_from_string(c(rownames(p.table), rownames(s.table))),
-    SE = c(as.vector(p.table[, 2]), rep(NA, n_smooth)),
-    Component = c(rep("conditional", n_cond), rep("smooth_terms", n_smooth))
-  )
+  if (!is.null(p.table)) {
+    d1 <- .data_frame(
+      Parameter = rownames(p.table),
+      SE = as.vector(p.table[, 2]),
+      Component = "conditional"
+    )
+  }
+
+  if (!is.null(s.table)) {
+    d2 <- .data_frame(
+      Parameter = rownames(s.table),
+      SE = NA,
+      Component = "smooth_terms"
+    )
+  }
+
+  insight::text_remove_backticks(rbind(d1, d2), verbose = FALSE)
 }
 
 
@@ -34,36 +45,39 @@ standard_error.gam <- function(model, ...) {
 p_value.gam <- function(model, ...) {
   p.table <- summary(model)$p.table
   s.table <- summary(model)$s.table
+  d1 <- d2 <- NULL
 
-  d1 <- .data_frame(
-    Parameter = rownames(p.table),
-    p = as.vector(p.table[, 4]),
-    Component = "conditional"
-  )
+  if (!is.null(p.table)) {
+    d1 <- .data_frame(
+      Parameter = rownames(p.table),
+      p = as.vector(p.table[, 4]),
+      Component = "conditional"
+    )
+  }
 
-  d2 <- .data_frame(
-    Parameter = rownames(s.table),
-    p = as.vector(s.table[, 4]),
-    Component = "smooth_terms"
-  )
+  if (!is.null(s.table)) {
+    d2 <- .data_frame(
+      Parameter = rownames(s.table),
+      p = as.vector(s.table[, 4]),
+      Component = "smooth_terms"
+    )
+  }
 
-  .remove_backticks_from_parameter_names(rbind(d1, d2))
+  insight::text_remove_backticks(rbind(d1, d2), verbose = FALSE)
 }
 
 
 #' @export
 simulate_model.gam <- function(model, iterations = 1000, ...) {
-  insight::check_if_installed("MASS")
-
   if (is.null(iterations)) iterations <- 1000
 
   beta <- stats::coef(model)
-  varcov <- insight::get_varcov(model, component = "all")
+  varcov <- insight::get_varcov(model, component = "all", ...)
 
-  out <- as.data.frame(MASS::mvrnorm(n = iterations, mu = beta, Sigma = varcov))
+  out <- as.data.frame(.mvrnorm(n = iterations, mu = beta, Sigma = varcov))
 
   class(out) <- c("parameters_simulate_model", class(out))
-  attr(out, "object_name") <- .safe_deparse(substitute(model))
+  attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(model))
   out
 }
 
@@ -74,8 +88,7 @@ simulate_model.gam <- function(model, iterations = 1000, ...) {
 
 
 #' @export
-model_parameters.list <- function(model,
-                                  ...) {
+model_parameters.list <- function(model, ...) {
   if ("gam" %in% names(model)) {
     model <- model$gam
     class(model) <- c("gam", "lm", "glm")
@@ -84,13 +97,13 @@ model_parameters.list <- function(model,
     model <- model$pamobject
     model_parameters(model, ...)
   } else {
-    stop("We don't recognize this object of class 'list'. Please raise an issue.")
+    insight::format_error("We don't recognize this object of class `list`. Please raise an issue.")
   }
 }
 
 
 #' @export
-ci.list <- function(x, ci = .95, ...) {
+ci.list <- function(x, ci = 0.95, ...) {
   if ("gam" %in% names(x)) {
     x <- x$gam
     class(x) <- c("gam", "lm", "glm")
