@@ -1,6 +1,7 @@
+#' @rdname model_parameters.merMod
 #' @export
 model_parameters.merModList <- function(model,
-                                        ci = .95,
+                                        ci = 0.95,
                                         exponentiate = FALSE,
                                         p_adjust = NULL,
                                         verbose = TRUE,
@@ -13,19 +14,18 @@ model_parameters.merModList <- function(model,
     merge_by = "Parameter",
     standardize = NULL,
     exponentiate = exponentiate,
-    robust = FALSE,
     p_adjust = p_adjust,
     ...
   )
 
-  attr(out, "object_name") <- deparse(substitute(model), width.cutoff = 500)
+  attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(model))
   out
 }
 
 
 #' @export
-ci.merModList <- function(x, ci = .95, ...) {
-  .ci_generic(model = x, ci = ci, dof = NULL, robust = FALSE, component = "conditional")
+ci.merModList <- function(x, ci = 0.95, ...) {
+  .ci_generic(model = x, ci = ci, dof = NULL, component = "conditional", ...)
 }
 
 
@@ -36,7 +36,7 @@ standard_error.merModList <- function(model, ...) {
     Parameter = s$fe$term,
     SE = s$fe$std.error
   )
-  .remove_backticks_from_parameter_names(out)
+  insight::text_remove_backticks(out, verbose = FALSE)
 }
 
 
