@@ -36,7 +36,7 @@
 #' @inheritParams simulate_model
 #' @export
 model_parameters.mlm <- function(model,
-                                 ci = .95,
+                                 ci = 0.95,
                                  vcov = NULL,
                                  vcov_args = NULL,
                                  bootstrap = FALSE,
@@ -59,7 +59,7 @@ model_parameters.mlm <- function(model,
     p_adjust = p_adjust,
     ...
   )
-  attr(out, "object_name") <- deparse(substitute(model), width.cutoff = 500)
+  attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(model))
   out
 }
 
@@ -135,7 +135,7 @@ p_value.mlm <- function(model, vcov = NULL, vcov_args = NULL, ...) {
 ci.mlm <- function(x,
                    vcov = NULL,
                    vcov_args = NULL,
-                   ci = .95, ...) {
+                   ci = 0.95, ...) {
   # .ci_generic may not handle weights properly (not sure)
   if (is.null(insight::find_weights(x)) && is.null(vcov)) {
     out <- lapply(ci, function(i) {
@@ -153,23 +153,26 @@ ci.mlm <- function(x,
 
     # .ci_generic does handle `vcov` correctly.
   } else {
-    out <- .data_frame(.ci_generic(x,
-      ci = ci,
-      vcov = vcov,
-      vcov_args = vcov_args,
-      ...
-    ))
+    out <- .data_frame(
+      .ci_generic(
+        x,
+        ci = ci,
+        vcov = vcov,
+        vcov_args = vcov_args,
+        ...
+      )
+    )
 
     resp <- insight::get_parameters(x)$Response
     if (!"Reponse" %in% colnames(out) && nrow(out) == length(resp)) {
       out[["Response"]] <- resp
     } else {
       if (!isTRUE(all(out$Response == resp))) {
-        stop(insight::format_message(
-          "Unable to assign labels to the model's parameters. Please report",
-          "this problem to the `parameters` Issue Tracker:",
-          "https://github.com/easystats/parameters/issues"
-        ), call. = FALSE)
+        insight::format_error(
+          "Unable to assign labels to the model's parameters.",
+          "Please report this problem to the {.pkg parameters} issue tracker:",
+          "{.url https://github.com/easystats/parameters/issues}"
+        )
       }
     }
   }
@@ -180,13 +183,13 @@ ci.mlm <- function(x,
 #' @export
 simulate_model.mlm <- function(model, iterations = 1000, ...) {
   responses <- insight::find_response(model, combine = FALSE)
-  out <- .simulate_model(model, iterations, component = "conditional", effects = "fixed")
+  out <- .simulate_model(model, iterations, component = "conditional", effects = "fixed", ...)
 
   cn <- paste0(colnames(out), rep(responses, each = length(colnames(out)) / length(responses)))
   colnames(out) <- cn
 
   class(out) <- c("parameters_simulate_model", class(out))
-  attr(out, "object_name") <- insight::safe_deparse(substitute(model))
+  attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(model))
   out
 }
 
@@ -195,7 +198,7 @@ simulate_model.mlm <- function(model, iterations = 1000, ...) {
 simulate_parameters.mlm <- function(model,
                                     iterations = 1000,
                                     centrality = "median",
-                                    ci = .95,
+                                    ci = 0.95,
                                     ci_method = "quantile",
                                     test = "p-value",
                                     ...) {
@@ -218,7 +221,7 @@ simulate_parameters.mlm <- function(model,
   }
 
   class(out) <- c("parameters_simulate", "see_parameters_simulate", class(out))
-  attr(out, "object_name") <- deparse(substitute(model), width.cutoff = 500)
+  attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(model))
   attr(out, "object_class") <- class(model)
   attr(out, "iterations") <- iterations
   attr(out, "ci") <- ci
