@@ -3,14 +3,15 @@
 # model parameters ---------------------
 
 
-#' @rdname model_parameters.cgam
+#' @rdname model_parameters.averaging
 #' @export
 model_parameters.rqss <- model_parameters.cgam
 
 
+#' @rdname model_parameters.averaging
 #' @export
 model_parameters.rqs <- function(model,
-                                 ci = .95,
+                                 ci = 0.95,
                                  bootstrap = FALSE,
                                  iterations = 1000,
                                  standardize = NULL,
@@ -28,7 +29,7 @@ model_parameters.rqs <- function(model,
     ...
   )
 
-  attr(out, "object_name") <- deparse(substitute(model), width.cutoff = 500)
+  attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(model))
   out
 }
 
