@@ -2,8 +2,9 @@
 #'
 #' Parameters from Bayesian models.
 #'
-#' @param model Bayesian model (including SEM from \pkg{blavaan}. May also be
-#'   a data frame with posterior samples.
+#' @param model Bayesian model (including SEM from **blavaan**. May also be
+#'   a data frame with posterior samples, however, `as_draws` must be set to
+#'   `TRUE` (else, for data frames `NULL` is returned).
 #' @param ci Credible Interval (CI) level. Default to `0.95` (`95%`). See
 #'   [bayestestR::ci()] for further details.
 #' @param group_level Logical, for multilevel models (i.e. models with random
@@ -12,9 +13,9 @@
 #'   `group_level = FALSE` (the default), only information on SD and COR
 #'   are shown.
 #' @param component Which type of parameters to return, such as parameters for the
-#'   conditional model, the zero-inflated part of the model, the dispersion
+#'   conditional model, the zero-inflation part of the model, the dispersion
 #'   term, or other auxiliary parameters be returned? Applies to models with
-#'   zero-inflated and/or dispersion formula, or if parameters such as `sigma`
+#'   zero-inflation and/or dispersion formula, or if parameters such as `sigma`
 #'   should be included. May be abbreviated. Note that the *conditional*
 #'   component is also called *count* or *mean* component, depending on the
 #'   model. There are three convenient shortcuts: `component = "all"` returns
@@ -24,7 +25,10 @@
 #'   argument - but no auxiliary parameters). For `component = "distributional"`
 #'   (or `"auxiliary"`), components like `sigma`, `dispersion`, or `beta`
 #'   (and other auxiliary parameters) are returned.
-#'
+#' @param as_draws Logical, if `TRUE` and `model` is of class `data.frame`,
+#'   the data frame is treated as posterior samples and handled similar to
+#'   Bayesian models. All arguments in `...` are passed to
+#'   `model_parameters.draws()`.
 #' @inheritParams model_parameters.default
 #' @inheritParams bayestestR::describe_posterior
 #' @inheritParams insight::get_parameters
@@ -38,7 +42,7 @@
 #'   `bf_prior` and `priors` are ignored. \cr \cr There is also a
 #'   [`plot()`-method](https://easystats.github.io/see/articles/parameters.html)
 #'   implemented in the
-#'   \href{https://easystats.github.io/see/}{\pkg{see}-package}.
+#'   [**see**-package](https://easystats.github.io/see/).
 #'
 #' @inheritSection model_parameters Confidence intervals and approximation of degrees of freedom
 #'
@@ -58,9 +62,9 @@
 model_parameters.stanreg <- function(model,
                                      centrality = "median",
                                      dispersion = FALSE,
-                                     ci = .95,
-                                     ci_method = "hdi",
-                                     test = c("pd", "rope"),
+                                     ci = 0.95,
+                                     ci_method = "eti",
+                                     test = "pd",
                                      rope_range = "default",
                                      rope_ci = 0.95,
                                      bf_prior = NULL,
@@ -72,11 +76,8 @@ model_parameters.stanreg <- function(model,
                                      group_level = FALSE,
                                      keep = NULL,
                                      drop = NULL,
-                                     parameters = keep,
                                      verbose = TRUE,
                                      ...) {
-
-
   # Processing
   params <- .extract_parameters_bayesian(
     model,
@@ -99,14 +100,19 @@ model_parameters.stanreg <- function(model,
   )
 
   if (effects != "fixed") {
-    random_effect_levels <- which(params$Effects %in% "random" & grepl("^(?!Sigma\\[)(.*)", params$Parameter, perl = TRUE))
-    if (length(random_effect_levels) && isFALSE(group_level)) params <- params[-random_effect_levels, ]
+    random_effect_levels <- which(
+      params$Effects %in% "random" & !startsWith(params$Parameter, "Sigma[")
+    )
+    if (length(random_effect_levels) && isFALSE(group_level)) {
+      params <- params[-random_effect_levels, , drop = FALSE]
+    }
   }
 
+  ## TODO: can we use the regular pretty-name-formatting?
   params <- .add_pretty_names(params, model)
-  if (isTRUE(exponentiate) || identical(exponentiate, "nongaussian")) {
-    params <- .exponentiate_parameters(params, model, exponentiate)
-  }
+
+  # exponentiate coefficients and SE/CI, if requested
+  params <- .exponentiate_parameters(params, model, exponentiate)
 
   params <- .add_model_parameters_attributes(
     params,
@@ -114,13 +120,14 @@ model_parameters.stanreg <- function(model,
     ci,
     exponentiate,
     ci_method = ci_method,
+    group_level = group_level,
     verbose = verbose,
     ...
   )
 
   attr(params, "parameter_info") <- insight::clean_parameters(model)
-  attr(params, "object_name") <- deparse(substitute(model), width.cutoff = 500)
-  class(params) <- c("parameters_stan", "parameters_model", "see_parameters_model", class(params))
+  attr(params, "object_name") <- insight::safe_deparse_symbol(substitute(model))
+  class(params) <- c("parameters_model", "see_parameters_model", class(params))
 
   params
 }
@@ -130,8 +137,8 @@ model_parameters.stanreg <- function(model,
 model_parameters.stanmvreg <- function(model,
                                        centrality = "median",
                                        dispersion = FALSE,
-                                       ci = .95,
-                                       ci_method = "hdi",
+                                       ci = 0.95,
+                                       ci_method = "eti",
                                        test = "pd",
                                        rope_range = "default",
                                        rope_ci = 0.95,
@@ -142,11 +149,8 @@ model_parameters.stanmvreg <- function(model,
                                        standardize = NULL,
                                        keep = NULL,
                                        drop = NULL,
-                                       parameters = keep,
                                        verbose = TRUE,
                                        ...) {
-
-
   # Processing
   params <- .extract_parameters_bayesian(
     model,
@@ -172,7 +176,7 @@ model_parameters.stanmvreg <- function(model,
   params <- .add_pretty_names(params, model)
 
   attr(params, "ci") <- ci
-  attr(params, "object_name") <- deparse(substitute(model), width.cutoff = 500)
+  attr(params, "object_name") <- insight::safe_deparse_symbol(substitute(model))
   class(params) <- c("parameters_model", "see_parameters_model", class(params))
 
   params
