@@ -14,6 +14,7 @@
 
 # anova ----------------------
 
+#' @rdname model_parameters.averaging
 model_parameters.t1way <- function(model, keep = NULL, verbose = TRUE, ...) {
   parameters <- .extract_wrs2_t1way(model)
   parameters <- .add_htest_parameters_attributes(parameters, model, ...)
@@ -22,7 +23,7 @@ model_parameters.t1way <- function(model, keep = NULL, verbose = TRUE, ...) {
 }
 
 .extract_wrs2_t1way <- function(model) {
-  fcall <- .safe_deparse(model$call)
+  fcall <- insight::safe_deparse(model$call)
   # effect sizes are by default contained for `t1way` but not `rmanova`
   if (grepl("^(t1way|WRS2::t1way)", fcall)) {
     data.frame(
@@ -33,7 +34,7 @@ model_parameters.t1way <- function(model, keep = NULL, verbose = TRUE, ...) {
       "Method" = "A heteroscedastic one-way ANOVA for trimmed means",
       "Estimate" = model$effsize,
       "CI" = 1 - model$alpha,
-      "CI_low" =  model$effsize_ci[1],
+      "CI_low" = model$effsize_ci[1],
       "CI_high" = model$effsize_ci[2],
       "Effectsize" = "Explanatory measure of effect size",
       stringsAsFactors = FALSE
@@ -50,6 +51,7 @@ model_parameters.t1way <- function(model, keep = NULL, verbose = TRUE, ...) {
   }
 }
 
+#' @rdname model_parameters.averaging
 #' @export
 model_parameters.med1way <- function(model, verbose = TRUE, ...) {
   parameters <- .extract_wrs2_med1way(model)
@@ -68,6 +70,7 @@ model_parameters.med1way <- function(model, verbose = TRUE, ...) {
   )
 }
 
+#' @rdname model_parameters.averaging
 #' @export
 model_parameters.dep.effect <- function(model,
                                         keep = NULL,
@@ -120,6 +123,7 @@ model_parameters.dep.effect <- function(model,
 
 # t-test ----------------------
 
+#' @rdname model_parameters.averaging
 #' @export
 model_parameters.yuen <- function(model, verbose = TRUE, ...) {
   parameters <- .extract_wrs2_yuen(model)
@@ -129,7 +133,7 @@ model_parameters.yuen <- function(model, verbose = TRUE, ...) {
 }
 
 .extract_wrs2_yuen <- function(model) {
-  fcall <- .safe_deparse(model$call)
+  fcall <- insight::safe_deparse(model$call)
 
   # the latter regexe covers `rlang::exec` or `do.call` instances
 
@@ -143,8 +147,8 @@ model_parameters.yuen <- function(model, verbose = TRUE, ...) {
       "Method" = "Yuen's test on trimmed means for independent samples",
       "Difference" = model$diff,
       "CI" = 0.95,
-      "Difference_CI_low" =  model$conf.int[1],
-      "Difference_CI_high" =  model$conf.int[2],
+      "Difference_CI_low" = model$conf.int[1],
+      "Difference_CI_high" = model$conf.int[2],
       "Estimate" = model$effsize,
       "Effectsize" = "Explanatory measure of effect size",
       stringsAsFactors = FALSE
@@ -158,8 +162,8 @@ model_parameters.yuen <- function(model, verbose = TRUE, ...) {
       "Method" = "Yuen's test on trimmed means for dependent samples",
       "Difference" = model$diff,
       "CI" = 0.95,
-      "Difference_CI_low" =  model$conf.int[1],
-      "Difference_CI_high" =  model$conf.int[2],
+      "Difference_CI_low" = model$conf.int[1],
+      "Difference_CI_high" = model$conf.int[2],
       "Estimate" = model$effsize,
       "Effectsize" = "Explanatory measure of effect size",
       stringsAsFactors = FALSE
@@ -215,7 +219,7 @@ model_parameters.robtab <- function(model, verbose = TRUE, ...) {
 
 
 .extract_wrs2_robtab <- function(model) {
-  fcall <- .safe_deparse(model$call)
+  fcall <- insight::safe_deparse(model$call)
 
   # dataframe
   out <- as.data.frame(model$partable)
@@ -254,8 +258,8 @@ model_parameters.onesampb <- function(model, verbose = TRUE, ...) {
   data.frame(
     "Estimate" = model$estimate,
     "CI" = 1 - model$alpha,
-    "CI_low" =  model$ci[1],
-    "CI_high" =  model$ci[2],
+    "CI_low" = model$ci[1],
+    "CI_high" = model$ci[2],
     "p" = model$p.value,
     "n_Obs" = model$n,
     "Effectsize" = "Robust location measure",
@@ -280,8 +284,8 @@ model_parameters.trimcibt <- function(model, verbose = TRUE, ...) {
     "Method" = "Bootstrap-t method for one-sample test",
     "Estimate" = model$estimate[[1]],
     "CI" = 1 - model$alpha,
-    "CI_low" =  model$ci[1],
-    "CI_high" =  model$ci[2],
+    "CI_low" = model$ci[1],
+    "CI_high" = model$ci[2],
     "Effectsize" = "Trimmed mean",
     stringsAsFactors = FALSE
   )
@@ -302,8 +306,8 @@ model_parameters.AKP <- function(model, verbose = TRUE, ...) {
   data.frame(
     "Estimate" = model$AKPeffect,
     "CI" = 1 - model$alpha,
-    "CI_low" =  model$AKPci[1],
-    "CI_high" =  model$AKPci[2],
+    "CI_low" = model$AKPci[1],
+    "CI_high" = model$AKPci[2],
     "Effectsize" = "Algina-Keselman-Penfield robust standardized difference",
     stringsAsFactors = FALSE
   )
@@ -320,8 +324,8 @@ model_parameters.wmcpAKP <- function(model, verbose = TRUE, ...) {
   data.frame(
     "Estimate" = model[[1]],
     "CI" = 0.95,
-    "CI_low" =  model[[2]],
-    "CI_high" =  model[[3]],
+    "CI_low" = model[[2]],
+    "CI_high" = model[[3]],
     "Effectsize" = "Algina-Keselman-Penfield robust standardized difference average",
     stringsAsFactors = FALSE
   )
