@@ -1,5 +1,19 @@
 #' Type of model parameters
 #'
+#' In a regression model, the parameters do not all have the meaning. For
+#' instance, the intercept has to be interpreted as theoretical outcome value
+#' under some conditions (when predictors are set to 0), whereas other
+#' coefficients are to be interpreted as amounts of change. Others, such as
+#' interactions, represent changes in another of the parameter. The
+#' `parameters_type` function attempts to retrieve information and meaning
+#' of parameters. It outputs a dataframe of information for each parameters,
+#' such as the `Type` (whether the parameter corresponds to a factor or a
+#' numeric predictor, or whether it is a (regular) interaction or a nested
+#' one), the `Link` (whether the parameter can be interpreted as a mean
+#' value, the slope of an association or a difference between two levels) and,
+#' in the case of interactions, which other parameters is impacted by which
+#' parameter.
+#'
 #' @param model A statistical model.
 #' @param ... Arguments passed to or from other methods.
 #'
@@ -40,7 +54,6 @@
 #' @return A data frame.
 #' @export
 parameters_type <- function(model, ...) {
-
   # Get info
   params <- data.frame(
     Parameter = insight::find_parameters(model, effects = "fixed", flatten = TRUE),
@@ -79,10 +92,20 @@ parameters_type <- function(model, ...) {
   }
 
 
-  data <- insight::get_data(model)
+  data <- insight::get_data(model, source = "mf", verbose = FALSE)
   if (is.null(data) || inherits(data, "ts") || nrow(data) == 0) {
     return(NULL)
   }
+
+  # convert on-the-fly-factors back from numeric to factors
+  data[] <- lapply(data, function(i) {
+    if (isTRUE(attributes(i)$factor)) {
+      as.factor(i)
+    } else {
+      i
+    }
+  })
+
   reference <- .list_factors_numerics(data, model)
 
   # Get types
@@ -106,6 +129,7 @@ parameters_type <- function(model, ...) {
       }
     }
   }
+
   for (i in unique(out$Secondary_Parameter)) {
     if (!is.na(i) && i %in% out$Parameter) {
       .param_type <- out[!is.na(out$Parameter) & out$Parameter == i, "Type"]
@@ -132,12 +156,9 @@ parameters_type <- function(model, ...) {
 
 
 
-
-
 #' @keywords internal
 .parameters_type <- function(name, data, reference) {
   if (grepl(":", name, fixed = TRUE)) {
-
     # Split
     var <- unlist(strsplit(name, ":", fixed = TRUE))
     if (length(var) > 2) {
@@ -160,7 +181,6 @@ parameters_type <- function(model, ...) {
 
 
 
-#' @importFrom utils tail head
 #' @keywords internal
 .parameters_type_basic <- function(name, data, reference, brackets = c("[", "]")) {
   if (is.na(name)) {
@@ -215,21 +235,18 @@ parameters_type <- function(model, ...) {
     } else {
       type <- "poly"
     }
-    vars <- gsub("poly(", "", name, fixed = TRUE)
-    vars <- unlist(strsplit(vars, ", ", fixed = TRUE))
-    var <- vars[[1]]
-    degree <- vars[[2]]
-    degree <- substr(vars[[2]], nchar(vars[[2]]), nchar(vars[[2]]))
+    var <- .poly_info(name, "name")
+    degree <- .poly_info(name, "degree")
     return(c(type, "Association", name, var, degree, NA))
 
     # Splines
-  } else if (grepl("(bs|ns|psline|lspline|rcs)\\(", name)) {
+  } else if (grepl("(bs|ns|psline|lspline|rcs|mSpline)\\(", name)) {
     type <- "spline"
-    var <- gsub("(bs|ns|psline|lspline|rcs)\\((.*)\\)(\\d)", "\\2", name)
+    var <- gsub("(bs|ns|psline|lspline|rcs|mSpline)\\((.*)\\)(\\d)", "\\2", name)
     if (grepl(",", var, fixed = TRUE)) {
       var <- substr(var, start = 0, stop = regexpr(",", var, fixed = TRUE) - 1)
     }
-    degree <- gsub("(bs|ns|psline|lspline|rcs)\\((.*)\\)(\\d)", "\\3", name)
+    degree <- gsub("(bs|ns|psline|lspline|rcs|mSpline)\\((.*)\\)(\\d)", "\\3", name)
     return(c(type, "Association", name, var, degree, NA))
 
     # log-transformation
@@ -251,7 +268,7 @@ parameters_type <- function(model, ...) {
     return(c(type, "Association", name, var, NA, NA))
 
     # sqrt-transformation
-  } else if (grepl("sqrt\\(", name)) {
+  } else if (grepl("sqrt(", name, fixed = TRUE)) {
     type <- "squareroot"
     var <- gsub("sqrt\\((.*)\\)", "\\1", name)
     if (grepl(",", var, fixed = TRUE)) {
@@ -260,17 +277,17 @@ parameters_type <- function(model, ...) {
     return(c(type, "Association", name, var, NA, NA))
 
     # As Is
-  } else if (grepl("^I\\(", name)) {
+  } else if (startsWith(name, "I(")) {
     type <- "asis"
     var <- gsub("^I\\((.*)\\)", "\\1", name)
     return(c(type, "Association", name, var, NA, NA))
 
     # Smooth
-  } else if (grepl("^s\\(", name)) {
+  } else if (startsWith(name, "s(")) {
     return(c("smooth", "Association", name, NA, NA, NA))
 
     # Smooth
-  } else if (grepl("^smooth_", name)) {
+  } else if (startsWith(name, "smooth_")) {
     return(c("smooth", "Association", gsub("^smooth_(.*)\\[(.*)\\]", "\\2", name), NA, NA, NA))
   } else {
     return(c("unknown", NA, NA, NA, NA, NA))
@@ -279,20 +296,33 @@ parameters_type <- function(model, ...) {
 
 
 
+#' @keywords internal
+.poly_info <- function(x, what = "degree") {
+  if (what == "degree") {
+    subs <- "\\4"
+  } else {
+    subs <- "\\2"
+  }
+  p <- "(.*)poly\\((.*),\\s(.*)\\)(.*)"
+  tryCatch(insight::trim_ws(sub(p, replacement = subs, x)),
+    error = function(x) 1
+  )
+}
+
+
+
 #' @keywords internal
 .list_factors_numerics <- function(data, model) {
   out <- list()
-  out$numeric <- names(data[sapply(data, is.numeric)])
+
+  # retrieve numerics
+  .check_for_numerics <- function(x) {
+    is.numeric(x) && !isTRUE(attributes(x)$factor)
+  }
+  out$numeric <- names(data[vapply(data, .check_for_numerics, TRUE)])
 
   # get contrast coding
-  contrast_coding <- tryCatch(
-    {
-      model$contrasts
-    },
-    error = function(e) {
-      NULL
-    }
-  )
+  contrast_coding <- tryCatch(model$contrasts, error = function(e) NULL)
 
   # if contrasts are given as matrix, find related contrast name
   if (!is.null(contrast_coding)) {
@@ -321,18 +351,18 @@ parameters_type <- function(model, ...) {
   }
 
   # Ordered factors
-  out$ordered <- names(data[sapply(data, is.ordered)])
+  out$ordered <- names(data[vapply(data, is.ordered, TRUE)])
 
   # Factors
-  out$factor <- names(data[sapply(data, is.factor) | sapply(data, is.character)])
+  out$factor <- names(data[vapply(data, is.factor, TRUE) | vapply(data, is.character, TRUE)])
 
   out$levels <- NA
   out$levels_parent <- NA
   for (fac in out$factor) {
     if ((fac %in% out$ordered && is.null(contrast_coding[[fac]])) || (!is.null(contrast_coding[[fac]]) && any(contrast_coding[[fac]] %in% "contr.poly"))) {
-      levels <- paste0(fac, c(".L", ".Q", ".C", paste0("^", 4:1000))[1:length(unique(data[[fac]]))])
+      levels <- paste0(fac, c(".L", ".Q", ".C", paste0("^", 4:1000))[seq_along(unique(data[[fac]]))])
     } else if (!is.null(contrast_coding[[fac]]) && any(contrast_coding[[fac]] %in% c("contr.SAS2", "contr.sum", "contr.bayes", "contr.helmert"))) {
-      levels <- paste0(fac, 1:length(unique(data[[fac]])))
+      levels <- paste0(fac, seq_along(unique(data[[fac]])))
     } else if (!is.null(contrast_coding[[fac]]) && any(contrast_coding[[fac]] %in% c("contr.treatment2"))) {
       levels <- paste0(fac, 2:length(unique(data[[fac]])))
     } else if (!is.null(contrast_coding[[fac]]) && any(contrast_coding[[fac]] %in% c("contr.SAS"))) {
