@@ -3,8 +3,7 @@
 #' This function performs an automated selection of the 'best' parameters,
 #' updating and returning the "best" model.
 #'
-#' @param model A statistical model (of class `lm`, `glm`,
-#'   `merMod`, `stanreg` or `brmsfit`).
+#' @param model A statistical model (of class `lm`, `glm`, or `merMod`).
 #' @param ... Arguments passed to or from other methods.
 #'
 #' @details
@@ -21,10 +20,6 @@
 #'     the cAIC can't be improved further.
 #'   }
 #'
-#'   \subsection{Bayesian models}{
-#'     For Bayesian models, it uses the \pkg{projpred} package.
-#'   }
-#'
 #' @examples
 #' model <- lm(mpg ~ ., data = mtcars)
 #' select_parameters(model)
@@ -42,25 +37,6 @@
 #' }
 #' }
 #'
-#' \dontrun{
-#' # rstanarm -------------------------------------------
-#' if (require("rstanarm") && require("projpred")) {
-#'   model <- stan_glm(
-#'     mpg ~ .,
-#'     data = mtcars,
-#'     iter = 500, refresh = 0, verbose = FALSE
-#'   )
-#'   select_parameters(model, cross_validation = TRUE)
-#'
-#'   model <- stan_glm(
-#'     mpg ~ cyl * disp * hp,
-#'     data = mtcars,
-#'     iter = 500, refresh = 0, verbose = FALSE
-#'   )
-#'   select_parameters(model, cross_validation = FALSE)
-#' }
-#' }
-#'
 #' @return The model refitted with optimal number of parameters.
 #' @export
 select_parameters <- function(model, ...) {
@@ -76,13 +52,16 @@ select_parameters.lm <- function(model,
                                  steps = 1000,
                                  k = 2,
                                  ...) {
-  junk <- utils::capture.output(best <- stats::step(model,
-    trace = 0,
-    direction = direction,
-    steps = steps,
-    k = k,
-    ...
-  ))
+  junk <- utils::capture.output(
+    best <- stats::step(
+      model,
+      trace = 0,
+      direction = direction,
+      steps = steps,
+      k = k,
+      ...
+    )
+  )
 
   best
 }
@@ -115,13 +94,18 @@ select_parameters.merMod <- function(model,
   factors <- gsub(":", "/", factors, fixed = TRUE)
 
 
-  best <- suppressMessages(suppressWarnings(cAIC4::stepcAIC(model,
-    # slopeCandidates = nums,
-    groupCandidates = factors,
-    direction = direction,
-    steps = steps,
-    allowUseAcross = TRUE
-  )$finalModel))
+  best <- suppressMessages(
+    suppressWarnings(
+      cAIC4::stepcAIC(
+        model,
+        # slopeCandidates = nums,
+        groupCandidates = factors,
+        direction = direction,
+        steps = steps,
+        allowUseAcross = TRUE
+      )$finalModel
+    )
+  )
 
 
   # Using MuMIn's dredge(): works nicely BUT throws unnecessary warnings and requires to set global options for na.action even tho no NaNs.
