@@ -1,9 +1,6 @@
 .runThisTest <- Sys.getenv("RunAllparametersTests") == "yes"
 
-if (requiet("testthat") &&
-  requiet("parameters") &&
-  requiet("lme4") &&
-  requiet("GLMMadaptive")) {
+if (requiet("lme4") && requiet("GLMMadaptive") && requiet("glmmTMB")) {
   data("fish")
   data("cbpp")
 
@@ -49,7 +46,7 @@ if (requiet("testthat") &&
       tolerance = 1e-3
     )
 
-    expect_null(ci(m2, component = "zi"))
+    expect_null(suppressMessages(ci(m2, component = "zi")))
   })
 
 
@@ -82,7 +79,7 @@ if (requiet("testthat") &&
       tolerance = 1e-3
     )
 
-    expect_null(standard_error(m2, component = "zi"))
+    expect_null(suppressMessages(standard_error(m2, component = "zi")))
   })
 
 
@@ -114,7 +111,7 @@ if (requiet("testthat") &&
       tolerance = 1e-3
     )
 
-    expect_null(p_value(m2, component = "zi"))
+    expect_null(suppressMessages(p_value(m2, component = "zi")))
   })
 
 
@@ -135,7 +132,7 @@ if (requiet("testthat") &&
     {
       si <- Sys.info()
       if (!is.null(si["sysname"])) {
-        si["sysname"] == "Windows" || grepl("^mingw", R.version$os)
+        si["sysname"] == "Windows" || startsWith(R.version$os, "mingw")
       } else {
         FALSE
       }
@@ -159,19 +156,19 @@ if (requiet("testthat") &&
 
     test_that("model_parameters.mixed-ran_pars", {
       params <- model_parameters(model, effects = "random")
-      expect_equal(c(nrow(params), ncol(params)), c(7, 9))
-      expect_equal(
+      expect_identical(c(nrow(params), ncol(params)), c(7L, 9L))
+      expect_identical(
         colnames(params),
         c("Parameter", "Coefficient", "SE", "CI", "CI_low", "CI_high", "Effects", "Group", "Component")
       )
-      expect_equal(
+      expect_identical(
         params$Parameter,
         c(
-          "SD (Intercept)", "SD (DOY)", "Cor (Intercept~DOY: site)", "SD (Observations)",
-          "SD (Intercept)", "SD (DOP)", "Cor (Intercept~DOP: site)"
+          "SD (Intercept)", "SD (DOY)", "Cor (Intercept~DOY)", "SD (Observations)",
+          "SD (Intercept)", "SD (DOP)", "Cor (Intercept~DOP)"
         )
       )
-      expect_equal(
+      expect_identical(
         params$Component,
         c(
           "conditional", "conditional", "conditional", "conditional",
@@ -180,7 +177,7 @@ if (requiet("testthat") &&
       )
       expect_equal(
         params$Coefficient,
-        c(0.56552, 0.29951, 0.06307, 0, 1.02233, 0.38209, -0.17162),
+        c(0.56552, 0.29951, 0.06307, 1.61936, 1.02233, 0.38209, -0.17162),
         tolerance = 1e-2
       )
     })
