@@ -1,4 +1,6 @@
-if (requiet("testthat") && requiet("parameters") && requiet("effectsize") && utils::packageVersion("effectsize") > "0.4.5") {
+## TODO: add more tests for different htest objects and effectsize types
+
+if (requiet("effectsize")) {
   test_that("model_parameters.htest", {
     params <- model_parameters(cor.test(mtcars$mpg, mtcars$cyl, method = "pearson"))
     expect_equal(
@@ -34,19 +36,39 @@ if (requiet("testthat") && requiet("parameters") && requiet("effectsize") && uti
 
   data(mtcars)
   mp <- model_parameters(stats::chisq.test(table(mtcars$am)))
+
   test_that("model_parameters-chisq-test NULL", {
     expect_equal(mp$Chi2, 1.125, tolerance = 1e-3)
     expect_equal(colnames(mp), c("Chi2", "df", "p", "Method"))
   })
 
-  mp <- model_parameters(stats::chisq.test(table(mtcars$am)), phi = "adjusted", ci = 0.95)
-  test_that("model_parameters-chisq-test adjusted", {
-    expect_equal(mp$Chi2, 1.125, tolerance = 1e-3)
-    expect_equal(mp$phi_adjusted, 0.0538348, tolerance = 1e-3)
-    expect_equal(colnames(mp), c("Chi2", "df", "phi_adjusted", "CI", "phi_CI_low", "phi_CI_high", "p", "Method"))
+  mp2 <- suppressWarnings(model_parameters(stats::chisq.test(table(mtcars$am, mtcars$cyl))))
+
+  test_that("model_parameters-chisq-test two way table", {
+    expect_equal(mp2$Chi2, 8.740733, tolerance = 1e-3)
+    expect_equal(colnames(mp2), c("Chi2", "df", "p", "Method"))
   })
 
-  params <- model_parameters(t.test(iris$Sepal.Width, iris$Sepal.Length), standardized_d = TRUE)
+  test_that("model_parameters-chisq-test works with `svychisq` objects", {
+    requiet("survey")
+    data(api)
+
+    set.seed(123)
+    dclus1 <- svydesign(id = ~dnum, weights = ~pw, data = apiclus1, fpc = ~fpc)
+    m <- svychisq(~ sch.wide + stype, dclus1)
+    mp <- model_parameters(m)
+
+    expect_equal(mp$F, 5.19337, tolerance = 1e-3)
+    expect_equal(names(mp), c("F", "df", "df_error", "p", "Method"))
+  })
+
+  expect_message(mp <- model_parameters(stats::chisq.test(table(mtcars$am)), effectsize_type = "phi", ci = 0.95))
+  test_that("model_parameters-chisq-test adjusted", {
+    expect_equal(mp$Chi2, 1.125, tolerance = 1e-3)
+    expect_equal(colnames(mp), c("Chi2", "df", "p", "Method"))
+  })
+
+  params <- model_parameters(t.test(iris$Sepal.Width, iris$Sepal.Length), effectsize_type = "cohens_d")
   test_that("model_parameters-t-test standardized d", {
     expect_equal(params$Cohens_d, -4.210417, tolerance = 0.05)
     expect_equal(params$d_CI_low, -4.655306, tolerance = 0.05)
@@ -54,20 +76,20 @@ if (requiet("testthat") && requiet("parameters") && requiet("effectsize") && uti
       colnames(params),
       c(
         "Parameter1", "Parameter2", "Mean_Parameter1", "Mean_Parameter2",
-        "Difference", "CI", "CI_low", "CI_high", "t", "df_error", "Cohens_d", "d_CI_low",
-        "d_CI_high", "p", "Method", "Alternative"
+        "Difference", "CI", "CI_low", "CI_high", "Cohens_d", "d_CI_low",
+        "d_CI_high", "t", "df_error", "p", "Method", "Alternative"
       )
     )
   })
 
-  mp <- model_parameters(t.test(mtcars$mpg ~ mtcars$vs), standardized_d = TRUE, verbose = FALSE)
+  mp <- model_parameters(t.test(mtcars$mpg ~ mtcars$vs), effectsize_type = "cohens_d", verbose = FALSE)
   test_that("model_parameters-t-test standardized d", {
     expect_equal(mp$Cohens_d, -1.696032, tolerance = 1e-3)
     expect_equal(
       colnames(mp),
       c(
         "Parameter", "Group", "Mean_Group1", "Mean_Group2", "Difference", "CI",
-        "CI_low", "CI_high", "t", "df_error", "Cohens_d", "d_CI_low", "d_CI_high",
+        "CI_low", "CI_high", "Cohens_d", "d_CI_low", "d_CI_high", "t", "df_error",
         "p", "Method", "Alternative"
       )
     )
