@@ -1,4 +1,4 @@
-if (require("testthat") && require("parameters") && require("bbmle")) {
+if (requiet("bbmle")) {
   x <- 0:10
   y <- c(26, 17, 13, 12, 20, 5, 9, 8, 5, 4, 8)
   d <- data.frame(x, y)
@@ -10,10 +10,10 @@ if (require("testthat") && require("parameters") && require("bbmle")) {
 
   test_that("model_parameters.mle2", {
     params <- model_parameters(model)
-    testthat::expect_equal(params$SE, c(4.224444, 1.034797), tolerance = 1e-3)
-    testthat::expect_equal(
+    expect_equal(params$SE, c(4.224444, 1.034797), tolerance = 1e-3)
+    expect_equal(
       colnames(params),
-      c("Parameter", "Coefficient", "SE", "CI_low", "CI_high", "z", "df_error", "p")
+      c("Parameter", "Coefficient", "SE", "CI", "CI_low", "CI_high", "z", "df_error", "p")
     )
   })
 }
